class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QWebChannel(QObject):
    """"""
    def __init__(self, parent = None):
        '''void QWebChannel.__init__(QObject parent = None)'''
    def disconnectFrom(self, transport):
        '''void QWebChannel.disconnectFrom(QWebChannelAbstractTransport transport)'''
    def connectTo(self, transport):
        '''void QWebChannel.connectTo(QWebChannelAbstractTransport transport)'''
    blockUpdatesChanged = pyqtSignal() # void blockUpdatesChanged(bool) - signal
    def setBlockUpdates(self, block):
        '''void QWebChannel.setBlockUpdates(bool block)'''
    def blockUpdates(self):
        '''bool QWebChannel.blockUpdates()'''
        return bool()
    def deregisterObject(self, object):
        '''void QWebChannel.deregisterObject(QObject object)'''
    def registerObject(self, id, object):
        '''void QWebChannel.registerObject(str id, QObject object)'''
    def registeredObjects(self):
        '''dict-of-QString-QObject QWebChannel.registeredObjects()'''
        return {str():QObject()}
    def registerObjects(self, objects):
        '''void QWebChannel.registerObjects(dict-of-QString-QObject objects)'''


class QWebChannelAbstractTransport(QObject):
    """"""
    def __init__(self, parent = None):
        '''void QWebChannelAbstractTransport.__init__(QObject parent = None)'''
    messageReceived = pyqtSignal() # void messageReceived(const QJsonObjectamp;,QWebChannelAbstractTransport*) - signal
    def sendMessage(self, message):
        '''abstract void QWebChannelAbstractTransport.sendMessage(dict-of-str-QJsonValue message)'''





# AUTO-GENERATED FILE -- DO NOT EDIT

""" This is an interface to Python's internal parser. """

class ASTType(object):
  """ Intermediate representation of a Python parse tree. """

  pass

class ParserError(Exception):

  pass

__copyright__ = """Copyright 1995-1996 by Virginia Polytechnic Institute & State
University, Blacksburg, Virginia, USA, and Fred L. Drake, Jr., Reston,
Virginia, USA.  Portions copyright 1991-1995 by Stichting Mathematisch
Centrum, Amsterdam, The Netherlands."""
__package__ = None
__version__ = '0.5'

def _pickler():
  """ Returns the pickle magic to allow ST objects to be pickled. """
  pass

def ast2list():
  """ Creates a list-tree representation of an ST. """
  pass

def ast2tuple():
  """ Creates a tuple-tree representation of an ST. """
  pass

def compileast():
  """ Compiles an ST object into a code object. """
  pass

def compilest():
  """ Compiles an ST object into a code object. """
  pass

def expr():
  """ Creates an ST object from an expression. """
  pass

def isexpr():
  """ Determines if an ST object was created from an expression. """
  pass

def issuite():
  """ Determines if an ST object was created from a suite. """
  pass

def sequence2ast():
  """ Creates an ST object from a tree representation. """
  pass

def sequence2st():
  """ Creates an ST object from a tree representation. """
  pass

def st2list():
  """ Creates a list-tree representation of an ST. """
  pass

def st2tuple():
  """ Creates a tuple-tree representation of an ST. """
  pass

def suite():
  """ Creates an ST object from a suite. """
  pass

def tuple2ast():
  """ Creates an ST object from a tree representation. """
  pass

def tuple2st():
  """ Creates an ST object from a tree representation. """
  pass




class Add(): pass
class Sub(): pass
class Mul(): pass
class Floordiv(): pass
class Mod(): pass
class Divmod(): pass
class Pow(): pass
class Lshift(): pass
class Rshift(): pass
class And(): pass
class Xor(): pass
class Or(): pass

class Example():
    def __add__(self, other):
        return Add()
    def __sub__(self, other):
        return Sub()
    def __mul__(self, other):
        return Mul()
    def __floordiv__(self, other):
        return Floordiv()
    def __mod__(self, other):
        return Mod()
    def __divmod__(self, other):
        return Divmod()
    def __pow__(self, other, modulo):
        return Pow()
    def __lshift__(self, other):
        return Lshift()
    def __rshift__(self, other):
        return Rshift()
    def __and__(self, other):
        return And()
    def __xor__(self, other):
        return Xor()
    def __or__(self, other):
        return Or()



class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class KSettings():
    """"""
    class Dispatcher():
        """"""
        def syncConfiguration(self):
            '''static void KSettings.Dispatcher.syncConfiguration()'''
        def reparseConfiguration(self, componentName):
            '''static void KSettings.Dispatcher.reparseConfiguration(QString componentName)'''
        def componentNames(self):
            '''static list-of-QString KSettings.Dispatcher.componentNames()'''
            return [QString()]
        def configForComponentName(self, componentName):
            '''static unknown-type KSettings.Dispatcher.configForComponentName(QString componentName)'''
            return unknown-type()
        def registerComponent(self, componentData, recv, slot):
            '''static void KSettings.Dispatcher.registerComponent(KComponentData componentData, QObject recv, str slot)'''
    class PluginPage(KCModule):
        """"""
        def __init__(self, componentData, parent = None, args = QVariantList()):
            '''void KSettings.PluginPage.__init__(KComponentData componentData, QWidget parent = None, list-of-QVariant args = QVariantList())'''
        def defaults(self):
            '''void KSettings.PluginPage.defaults()'''
        def save(self):
            '''void KSettings.PluginPage.save()'''
        def load(self):
            '''void KSettings.PluginPage.load()'''
        def pluginSelector(self):
            '''KPluginSelector KSettings.PluginPage.pluginSelector()'''
            return KPluginSelector()
    class Dialog(KCMultiDialog):
        """"""
        def __init__(self, parent = None):
            '''void KSettings.Dialog.__init__(QWidget parent = None)'''
        def __init__(self, components, parent = None):
            '''void KSettings.Dialog.__init__(QStringList components, QWidget parent = None)'''
        pluginSelectionChanged = pyqtSignal() # void pluginSelectionChanged() - signal
        def showEvent(self):
            '''QShowEvent KSettings.Dialog.showEvent()'''
            return QShowEvent()
        def pluginInfos(self):
            '''list-of-KPluginInfo KSettings.Dialog.pluginInfos()'''
            return [KPluginInfo()]
        def allowComponentSelection(self):
            '''bool KSettings.Dialog.allowComponentSelection()'''
            return bool()
        def setAllowComponentSelection(self, allowSelection):
            '''void KSettings.Dialog.setAllowComponentSelection(bool allowSelection)'''
        def setComponentBlacklist(self, blacklist):
            '''void KSettings.Dialog.setComponentBlacklist(QStringList blacklist)'''
        def setKCMArguments(self, arguments):
            '''void KSettings.Dialog.setKCMArguments(QStringList arguments)'''
        def addPluginInfos(self, plugininfos):
            '''void KSettings.Dialog.addPluginInfos(list-of-KPluginInfo plugininfos)'''


class KCMultiDialog(KPageDialog):
    """"""
    def __init__(self, parent = None):
        '''void KCMultiDialog.__init__(QWidget parent = None)'''
    def __init__(self, pageWidget, parent, flags = 0):
        '''void KCMultiDialog.__init__(KPageWidget pageWidget, QWidget parent, Qt.WindowFlags flags = 0)'''
    def setButtons(self, buttonMask):
        '''void KCMultiDialog.setButtons(KDialog.ButtonCodes buttonMask)'''
    def slotHelpClicked(self):
        '''void KCMultiDialog.slotHelpClicked()'''
    def slotOkClicked(self):
        '''void KCMultiDialog.slotOkClicked()'''
    def slotApplyClicked(self):
        '''void KCMultiDialog.slotApplyClicked()'''
    def slotUser1Clicked(self):
        '''void KCMultiDialog.slotUser1Clicked()'''
    def slotDefaultClicked(self):
        '''void KCMultiDialog.slotDefaultClicked()'''
    configCommitted = pyqtSignal() # void configCommitted() - signal
    configCommitted = pyqtSignal() # void configCommitted(const QByteArrayamp;) - signal
    def clear(self):
        '''void KCMultiDialog.clear()'''
    def addModule(self, module, args = QStringList()):
        '''KPageWidgetItem KCMultiDialog.addModule(QString module, QStringList args = QStringList())'''
        return KPageWidgetItem()
    def addModule(self, moduleinfo, parent = None, args = QStringList()):
        '''KPageWidgetItem KCMultiDialog.addModule(KCModuleInfo moduleinfo, KPageWidgetItem parent = None, QStringList args = QStringList())'''
        return KPageWidgetItem()


class KCModuleInfo():
    """"""
    def __init__(self, desktopFile):
        '''void KCModuleInfo.__init__(QString desktopFile)'''
    def __init__(self, moduleInfo):
        '''void KCModuleInfo.__init__(unknown-type moduleInfo)'''
    def __init__(self, rhs):
        '''void KCModuleInfo.__init__(KCModuleInfo rhs)'''
    def __init__(self):
        '''void KCModuleInfo.__init__()'''
    def weight(self):
        '''int KCModuleInfo.weight()'''
        return int()
    def handle(self):
        '''QString KCModuleInfo.handle()'''
        return QString()
    def library(self):
        '''QString KCModuleInfo.library()'''
        return QString()
    def docPath(self):
        '''QString KCModuleInfo.docPath()'''
        return QString()
    def icon(self):
        '''QString KCModuleInfo.icon()'''
        return QString()
    def comment(self):
        '''QString KCModuleInfo.comment()'''
        return QString()
    def service(self):
        '''unknown-type KCModuleInfo.service()'''
        return unknown-type()
    def moduleName(self):
        '''QString KCModuleInfo.moduleName()'''
        return QString()
    def keywords(self):
        '''QStringList KCModuleInfo.keywords()'''
        return QStringList()
    def fileName(self):
        '''QString KCModuleInfo.fileName()'''
        return QString()
    def __ne__(self, rhs):
        '''bool KCModuleInfo.__ne__(KCModuleInfo rhs)'''
        return bool()
    def __eq__(self, rhs):
        '''bool KCModuleInfo.__eq__(KCModuleInfo rhs)'''
        return bool()


class KCModuleLoader():
    """"""
    # Enum KCModuleLoader.ErrorReporting
    __kdevpythondocumentation_builtin_None = 0
    Inline = 0
    Dialog = 0
    Both = 0

    def reportError(self, report, text, details, parent):
        '''static KCModule KCModuleLoader.reportError(KCModuleLoader.ErrorReporting report, QString text, QString details, QWidget parent)'''
        return KCModule()
    def showLastLoaderError(self, parent):
        '''static void KCModuleLoader.showLastLoaderError(QWidget parent)'''
    def unloadModule(self, mod):
        '''static void KCModuleLoader.unloadModule(KCModuleInfo mod)'''
    def loadModule(self, module, report, parent = None, args = QStringList()):
        '''static KCModule KCModuleLoader.loadModule(KCModuleInfo module, KCModuleLoader.ErrorReporting report, QWidget parent = None, QStringList args = QStringList())'''
        return KCModule()
    def loadModule(self, module, report, parent = None, args = QStringList()):
        '''static KCModule KCModuleLoader.loadModule(QString module, KCModuleLoader.ErrorReporting report, QWidget parent = None, QStringList args = QStringList())'''
        return KCModule()


class KCModuleProxy(QWidget):
    """"""
    def __init__(self, info, parent = None, args = QStringList()):
        '''void KCModuleProxy.__init__(KCModuleInfo info, QWidget parent = None, QStringList args = QStringList())'''
    def __init__(self, serviceName, parent = None, args = QStringList()):
        '''void KCModuleProxy.__init__(QString serviceName, QWidget parent = None, QStringList args = QStringList())'''
    def __init__(self, service, parent = None, args = QStringList()):
        '''void KCModuleProxy.__init__(unknown-type service, QWidget parent = None, QStringList args = QStringList())'''
    def showEvent(self):
        '''QShowEvent KCModuleProxy.showEvent()'''
        return QShowEvent()
    quickHelpChanged = pyqtSignal() # void quickHelpChanged() - signal
    childClosed = pyqtSignal() # void childClosed() - signal
    def deleteClient(self):
        '''void KCModuleProxy.deleteClient()'''
    def defaults(self):
        '''void KCModuleProxy.defaults()'''
    def minimumSizeHint(self):
        '''QSize KCModuleProxy.minimumSizeHint()'''
        return QSize()
    def dbusPath(self):
        '''QString KCModuleProxy.dbusPath()'''
        return QString()
    def dbusService(self):
        '''QString KCModuleProxy.dbusService()'''
        return QString()
    def moduleInfo(self):
        '''KCModuleInfo KCModuleProxy.moduleInfo()'''
        return KCModuleInfo()
    def realModule(self):
        '''KCModule KCModuleProxy.realModule()'''
        return KCModule()
    def changed(self):
        '''bool KCModuleProxy.changed()'''
        return bool()
    changed = pyqtSignal() # void changed(bool) - signal
    changed = pyqtSignal() # void changed(KCModuleProxy *) - signal
    def componentData(self):
        '''KComponentData KCModuleProxy.componentData()'''
        return KComponentData()
    def useRootOnlyMessage(self):
        '''bool KCModuleProxy.useRootOnlyMessage()'''
        return bool()
    def rootOnlyMessage(self):
        '''QString KCModuleProxy.rootOnlyMessage()'''
        return QString()
    def buttons(self):
        '''KCModule.Buttons KCModuleProxy.buttons()'''
        return KCModule.Buttons()
    def aboutData(self):
        '''KAboutData KCModuleProxy.aboutData()'''
        return KAboutData()
    def quickHelp(self):
        '''QString KCModuleProxy.quickHelp()'''
        return QString()
    def save(self):
        '''void KCModuleProxy.save()'''
    def load(self):
        '''void KCModuleProxy.load()'''


class KEmoticons(QObject):
    """"""
    def __init__(self):
        '''void KEmoticons.__init__()'''
    def parseMode(self):
        '''static KEmoticonsTheme.ParseMode KEmoticons.parseMode()'''
        return KEmoticonsTheme.ParseMode()
    def setParseMode(self, mode):
        '''static void KEmoticons.setParseMode(KEmoticonsTheme.ParseMode mode)'''
    def installTheme(self, archiveName):
        '''QStringList KEmoticons.installTheme(QString archiveName)'''
        return QStringList()
    def newTheme(self, name, service):
        '''KEmoticonsTheme KEmoticons.newTheme(QString name, unknown-type service)'''
        return KEmoticonsTheme()
    def setTheme(self, theme):
        '''static void KEmoticons.setTheme(KEmoticonsTheme theme)'''
    def setTheme(self, theme):
        '''static void KEmoticons.setTheme(QString theme)'''
    def themeList(self):
        '''static QStringList KEmoticons.themeList()'''
        return QStringList()
    def currentThemeName(self):
        '''static QString KEmoticons.currentThemeName()'''
        return QString()
    def theme(self):
        '''KEmoticonsTheme KEmoticons.theme()'''
        return KEmoticonsTheme()
    def theme(self, name):
        '''KEmoticonsTheme KEmoticons.theme(QString name)'''
        return KEmoticonsTheme()


class KEmoticonsProvider(QObject):
    """"""
    # Enum KEmoticonsProvider.AddEmoticonOption
    DoNotCopy = 0
    Copy = 0

    def __init__(self, parent = None):
        '''void KEmoticonsProvider.__init__(QObject parent = None)'''
    def removeEmoticonIndex(self, path, emoList):
        '''void KEmoticonsProvider.removeEmoticonIndex(QString path, QStringList emoList)'''
    def addEmoticonIndex(self, path, emoList):
        '''void KEmoticonsProvider.addEmoticonIndex(QString path, QStringList emoList)'''
    def removeEmoticonsMap(self, key):
        '''void KEmoticonsProvider.removeEmoticonsMap(QString key)'''
    def addEmoticonsMap(self, key, value):
        '''void KEmoticonsProvider.addEmoticonsMap(QString key, QStringList value)'''
    def clearEmoticonsMap(self):
        '''void KEmoticonsProvider.clearEmoticonsMap()'''
    def createNew(self):
        '''void KEmoticonsProvider.createNew()'''
    def emoticonsMap(self):
        '''dict-of-QString-QStringList KEmoticonsProvider.emoticonsMap()'''
        return dict-of-QString-QStringList()
    def fileName(self):
        '''QString KEmoticonsProvider.fileName()'''
        return QString()
    def themePath(self):
        '''QString KEmoticonsProvider.themePath()'''
        return QString()
    def setThemeName(self, name):
        '''void KEmoticonsProvider.setThemeName(QString name)'''
    def themeName(self):
        '''QString KEmoticonsProvider.themeName()'''
        return QString()
    def save(self):
        '''void KEmoticonsProvider.save()'''
    def addEmoticon(self, emo, text, option = None):
        '''bool KEmoticonsProvider.addEmoticon(QString emo, QString text, KEmoticonsProvider.AddEmoticonOption option = KEmoticonsProvider.DoNotCopy)'''
        return bool()
    def removeEmoticon(self, emo):
        '''bool KEmoticonsProvider.removeEmoticon(QString emo)'''
        return bool()
    def loadTheme(self, path):
        '''bool KEmoticonsProvider.loadTheme(QString path)'''
        return bool()
    class Emoticon():
        """"""
        matchText = None # QString - member
        matchTextEscaped = None # QString - member
        picHTMLCode = None # QString - member
        picPath = None # QString - member
        def __init__(self):
            '''void KEmoticonsProvider.Emoticon.__init__()'''
        def __init__(self):
            '''KEmoticonsProvider.Emoticon KEmoticonsProvider.Emoticon.__init__()'''
            return KEmoticonsProvider.Emoticon()
        def __ge__(self, e):
            '''bool KEmoticonsProvider.Emoticon.__ge__(KEmoticonsProvider.Emoticon e)'''
            return bool()
        def __lt__(self, e):
            '''bool KEmoticonsProvider.Emoticon.__lt__(KEmoticonsProvider.Emoticon e)'''
            return bool()


class KEmoticonsTheme():
    """"""
    # Enum KEmoticonsTheme.TokenType
    Undefined = 0
    Image = 0
    Text = 0

    # Enum KEmoticonsTheme.ParseModeEnum
    DefaultParse = 0
    StrictParse = 0
    RelaxedParse = 0
    SkipHTML = 0

    def __init__(self):
        '''void KEmoticonsTheme.__init__()'''
    def __init__(self, ket):
        '''void KEmoticonsTheme.__init__(KEmoticonsTheme ket)'''
    def __init__(self, p):
        '''void KEmoticonsTheme.__init__(KEmoticonsProvider p)'''
    def isNull(self):
        '''bool KEmoticonsTheme.isNull()'''
        return bool()
    def createNew(self):
        '''void KEmoticonsTheme.createNew()'''
    def emoticonsMap(self):
        '''dict-of-QString-QStringList KEmoticonsTheme.emoticonsMap()'''
        return dict-of-QString-QStringList()
    def fileName(self):
        '''QString KEmoticonsTheme.fileName()'''
        return QString()
    def themePath(self):
        '''QString KEmoticonsTheme.themePath()'''
        return QString()
    def setThemeName(self, name):
        '''void KEmoticonsTheme.setThemeName(QString name)'''
    def themeName(self):
        '''QString KEmoticonsTheme.themeName()'''
        return QString()
    def save(self):
        '''void KEmoticonsTheme.save()'''
    def addEmoticon(self, emo, text, option = None):
        '''bool KEmoticonsTheme.addEmoticon(QString emo, QString text, KEmoticonsProvider.AddEmoticonOption option = KEmoticonsProvider.DoNotCopy)'''
        return bool()
    def removeEmoticon(self, emo):
        '''bool KEmoticonsTheme.removeEmoticon(QString emo)'''
        return bool()
    def loadTheme(self, path):
        '''bool KEmoticonsTheme.loadTheme(QString path)'''
        return bool()
    def tokenize(self, message, mode = None):
        '''list-of-KEmoticonsTheme.Token KEmoticonsTheme.tokenize(QString message, KEmoticonsTheme.ParseMode mode = KEmoticonsTheme.DefaultParse)'''
        return [KEmoticonsTheme.Token()]
    def parseEmoticons(self, text, mode = None, exclude = QStringList()):
        '''QString KEmoticonsTheme.parseEmoticons(QString text, KEmoticonsTheme.ParseMode mode = KEmoticonsTheme.DefaultParse, QStringList exclude = QStringList())'''
        return QString()
    class ParseMode():
        """"""
        def __init__(self):
            '''KEmoticonsTheme.ParseMode KEmoticonsTheme.ParseMode.__init__()'''
            return KEmoticonsTheme.ParseMode()
        def __init__(self):
            '''int KEmoticonsTheme.ParseMode.__init__()'''
            return int()
        def __init__(self):
            '''void KEmoticonsTheme.ParseMode.__init__()'''
        def __bool__(self):
            '''int KEmoticonsTheme.ParseMode.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool KEmoticonsTheme.ParseMode.__ne__(KEmoticonsTheme.ParseMode f)'''
            return bool()
        def __eq__(self, f):
            '''bool KEmoticonsTheme.ParseMode.__eq__(KEmoticonsTheme.ParseMode f)'''
            return bool()
        def __invert__(self):
            '''KEmoticonsTheme.ParseMode KEmoticonsTheme.ParseMode.__invert__()'''
            return KEmoticonsTheme.ParseMode()
        def __and__(self, mask):
            '''KEmoticonsTheme.ParseMode KEmoticonsTheme.ParseMode.__and__(int mask)'''
            return KEmoticonsTheme.ParseMode()
        def __xor__(self, f):
            '''KEmoticonsTheme.ParseMode KEmoticonsTheme.ParseMode.__xor__(KEmoticonsTheme.ParseMode f)'''
            return KEmoticonsTheme.ParseMode()
        def __xor__(self, f):
            '''KEmoticonsTheme.ParseMode KEmoticonsTheme.ParseMode.__xor__(int f)'''
            return KEmoticonsTheme.ParseMode()
        def __or__(self, f):
            '''KEmoticonsTheme.ParseMode KEmoticonsTheme.ParseMode.__or__(KEmoticonsTheme.ParseMode f)'''
            return KEmoticonsTheme.ParseMode()
        def __or__(self, f):
            '''KEmoticonsTheme.ParseMode KEmoticonsTheme.ParseMode.__or__(int f)'''
            return KEmoticonsTheme.ParseMode()
        def __int__(self):
            '''int KEmoticonsTheme.ParseMode.__int__()'''
            return int()
        def __ixor__(self, f):
            '''KEmoticonsTheme.ParseMode KEmoticonsTheme.ParseMode.__ixor__(KEmoticonsTheme.ParseMode f)'''
            return KEmoticonsTheme.ParseMode()
        def __ior__(self, f):
            '''KEmoticonsTheme.ParseMode KEmoticonsTheme.ParseMode.__ior__(KEmoticonsTheme.ParseMode f)'''
            return KEmoticonsTheme.ParseMode()
        def __iand__(self, mask):
            '''KEmoticonsTheme.ParseMode KEmoticonsTheme.ParseMode.__iand__(int mask)'''
            return KEmoticonsTheme.ParseMode()
    class Token():
        """"""
        picHTMLCode = None # QString - member
        picPath = None # QString - member
        text = None # QString - member
        type = None # KEmoticonsTheme.TokenType - member
        def __init__(self):
            '''void KEmoticonsTheme.Token.__init__()'''
        def __init__(self, t, m):
            '''void KEmoticonsTheme.Token.__init__(KEmoticonsTheme.TokenType t, QString m)'''
        def __init__(self, t, m, p, html):
            '''void KEmoticonsTheme.Token.__init__(KEmoticonsTheme.TokenType t, QString m, QString p, QString html)'''
        def __init__(self):
            '''KEmoticonsTheme.Token KEmoticonsTheme.Token.__init__()'''
            return KEmoticonsTheme.Token()


class KIdleTime(QObject):
    """"""
    timeoutReached = pyqtSignal() # void timeoutReached(int) - signal
    timeoutReached = pyqtSignal() # void timeoutReached(int,int) - signal
    resumingFromIdle = pyqtSignal() # void resumingFromIdle() - signal
    def stopCatchingResumeEvent(self):
        '''void KIdleTime.stopCatchingResumeEvent()'''
    def catchNextResumeEvent(self):
        '''void KIdleTime.catchNextResumeEvent()'''
    def removeAllIdleTimeouts(self):
        '''void KIdleTime.removeAllIdleTimeouts()'''
    def removeIdleTimeout(self, identifier):
        '''void KIdleTime.removeIdleTimeout(int identifier)'''
    def addIdleTimeout(self, msec):
        '''int KIdleTime.addIdleTimeout(int msec)'''
        return int()
    def simulateUserActivity(self):
        '''void KIdleTime.simulateUserActivity()'''
    def idleTimeouts(self):
        '''unknown-type KIdleTime.idleTimeouts()'''
        return unknown-type()
    def idleTime(self):
        '''int KIdleTime.idleTime()'''
        return int()
    def instance(self):
        '''static KIdleTime KIdleTime.instance()'''
        return KIdleTime()


class KPluginSelector(QWidget):
    """"""
    # Enum KPluginSelector.PluginLoadMethod
    ReadConfigFile = 0
    IgnoreConfigFile = 0

    def __init__(self, parent = None):
        '''void KPluginSelector.__init__(QWidget parent = None)'''
    configCommitted = pyqtSignal() # void configCommitted(const QByteArrayamp;) - signal
    changed = pyqtSignal() # void changed(bool) - signal
    def updatePluginsState(self):
        '''void KPluginSelector.updatePluginsState()'''
    def isDefault(self):
        '''bool KPluginSelector.isDefault()'''
        return bool()
    def defaults(self):
        '''void KPluginSelector.defaults()'''
    def save(self):
        '''void KPluginSelector.save()'''
    def load(self):
        '''void KPluginSelector.load()'''
    def addPlugins(self, componentName, categoryName = QString(), categoryKey = QString(), config = None):
        '''void KPluginSelector.addPlugins(QString componentName, QString categoryName = QString(), QString categoryKey = QString(), unknown-type config = KSharedConfig.Ptr())'''
    def addPlugins(self, instance, categoryName = QString(), categoryKey = QString(), config = None):
        '''void KPluginSelector.addPlugins(KComponentData instance, QString categoryName = QString(), QString categoryKey = QString(), unknown-type config = KSharedConfig.Ptr())'''
    def addPlugins(self, pluginInfoList, pluginLoadMethod = None, categoryName = QString(), categoryKey = QString(), config = None):
        '''void KPluginSelector.addPlugins(list-of-KPluginInfo pluginInfoList, KPluginSelector.PluginLoadMethod pluginLoadMethod = KPluginSelector.ReadConfigFile, QString categoryName = QString(), QString categoryKey = QString(), unknown-type config = KSharedConfig.Ptr())'''


class KPrintPreview(KDialog):
    """"""
    def __init__(self, printer, parent = None):
        '''void KPrintPreview.__init__(QPrinter printer, QWidget parent = None)'''
    def isAvailable(self):
        '''static bool KPrintPreview.isAvailable()'''
        return bool()
    def showEvent(self, event):
        '''void KPrintPreview.showEvent(QShowEvent event)'''





#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
""":synopsis: Set handlers for asynchronous events.


This module provides mechanisms to use signal handlers in Python. Some general
rules for working with signals and their handlers:

* A handler for a particular signal, once set, remains installed until it is
explicitly reset (Python emulates the BSD style interface regardless of the
underlying implementation), with the exception of the handler for
:const:`SIGCHLD`, which follows the underlying implementation.

* There is no way to "block" signals temporarily from critical sections (since
this is not supported by all Unix flavors).

* Although Python signal handlers are called asynchronously as far as the Python
user is concerned, they can only occur between the "atomic" instructions of the
Python interpreter.  This means that signals arriving during long calculations
implemented purely in C (such as regular expression matches on large bodies of
text) may be delayed for an arbitrary amount of time.

* When a signal arrives during an I/O operation, it is possible that the I/O
operation raises an exception after the signal handler returns. This is
dependent on the underlying Unix system's semantics regarding interrupted system
calls.

* Because the C signal handler always returns, it makes little sense to catch
synchronous errors like :const:`SIGFPE` or :const:`SIGSEGV`.

* Python installs a small number of signal handlers by default: :const:`SIGPIPE`
is ignored (so write errors on pipes and sockets can be reported as ordinary
Python exceptions) and :const:`SIGINT` is translated into a
:exc:`KeyboardInterrupt` exception.  All of these can be overridden.

* Some care must be taken if both signals and threads are used in the same
program.  The fundamental thing to remember in using signals and threads
simultaneously is: always perform :func:`signal` operations in the main thread
of execution.  Any thread can perform an :func:`alarm`, :func:`getsignal`,
:func:`pause`, :func:`setitimer` or :func:`getitimer`; only the main thread
can set a new signal handler, and the main thread will be the only one to
receive signals (this is enforced by the Python :mod:`signal` module, even
if the underlying thread implementation supports sending signals to
individual threads).  This means that signals can't be used as a means of
inter-thread communication.  Use locks instead.

The variables defined in the :mod:`signal` module are:


"""
"""
This is one of two standard signal handling options; it will simply perform
the default function for the signal.  For example, on most systems the
default action for :const:`SIGQUIT` is to dump core and exit, while the
default action for :const:`SIGCHLD` is to simply ignore it.


"""
SIG_DFL = None
"""
This is another standard signal handler, which will simply ignore the given
signal.


"""
SIG_IGN = None
"""
All the signal numbers are defined symbolically.  For example, the hangup signal
is defined as :const:`signal.SIGHUP`; the variable names are identical to the
names used in C programs, as found in ``<signal.h>``. The Unix man page for
':cfunc:`signal`' lists the existing signals (on some systems this is
:manpage:`signal(2)`, on others the list is in :manpage:`signal(7)`). Note that
not all systems define the same set of signal names; only those names defined by
the system are defined by this module.


"""
SIG = None
"""
The signal corresponding to the CTRL+C keystroke event. This signal can
only be used with :func:`os.kill`.

Availability: Windows.

"""
CTRL_C_EVENT = None
"""
The signal corresponding to the CTRL+BREAK keystroke event. This signal can
only be used with :func:`os.kill`.

Availability: Windows.

"""
CTRL_BREAK_EVENT = None
"""
One more than the number of the highest signal number.


"""
NSIG = None
"""
Decrements interval timer in real time, and delivers :const:`SIGALRM` upon expiration.


"""
ITIMER_REAL = None
"""
Decrements interval timer only when the process is executing, and delivers
SIGVTALRM upon expiration.


"""
ITIMER_VIRTUAL = None
"""
Decrements interval timer both when the process executes and when the
system is executing on behalf of the process. Coupled with ITIMER_VIRTUAL,
this timer is usually used to profile the time spent by the application
in user and kernel space. SIGPROF is delivered upon expiration.


The :mod:`signal` module defines one exception:

"""
ITIMER_PROF = None
def alarm(time):
	"""
	If *time* is non-zero, this function requests that a :const:`SIGALRM` signal be
	sent to the process in *time* seconds. Any previously scheduled alarm is
	canceled (only one alarm can be scheduled at any time).  The returned value is
	then the number of seconds before any previously set alarm was to have been
	delivered. If *time* is zero, no alarm is scheduled, and any scheduled alarm is
	canceled.  If the return value is zero, no alarm is currently scheduled.  (See
	the Unix man page :manpage:`alarm(2)`.) Availability: Unix.
	
	
	"""
	pass
	
def getsignal(signalnum):
	"""
	Return the current signal handler for the signal *signalnum*. The returned value
	may be a callable Python object, or one of the special values
	:const:`signal.SIG_IGN`, :const:`signal.SIG_DFL` or :const:`None`.  Here,
	:const:`signal.SIG_IGN` means that the signal was previously ignored,
	:const:`signal.SIG_DFL` means that the default way of handling the signal was
	previously in use, and ``None`` means that the previous signal handler was not
	installed from Python.
	
	
	"""
	pass
	
def pause():
	"""
	Cause the process to sleep until a signal is received; the appropriate handler
	will then be called.  Returns nothing.  Not on Windows. (See the Unix man page
	:manpage:`signal(2)`.)
	
	
	"""
	pass
	
def setitimer(which,seconds,interval):
	"""
	Sets given interval timer (one of :const:`signal.ITIMER_REAL`,
	:const:`signal.ITIMER_VIRTUAL` or :const:`signal.ITIMER_PROF`) specified
	by *which* to fire after *seconds* (float is accepted, different from
	:func:`alarm`) and after that every *interval* seconds. The interval
	timer specified by *which* can be cleared by setting seconds to zero.
	
	When an interval timer fires, a signal is sent to the process.
	The signal sent is dependent on the timer being used;
	:const:`signal.ITIMER_REAL` will deliver :const:`SIGALRM`,
	:const:`signal.ITIMER_VIRTUAL` sends :const:`SIGVTALRM`,
	and :const:`signal.ITIMER_PROF` will deliver :const:`SIGPROF`.
	
	The old values are returned as a tuple: (delay, interval).
	
	Attempting to pass an invalid interval timer will cause an
	:exc:`ItimerError`.  Availability: Unix.
	
	"""
	pass
	
def getitimer(which):
	"""
	Returns current value of a given interval timer specified by *which*.
	Availability: Unix.
	
	"""
	pass
	
def set_wakeup_fd(fd):
	"""
	Set the wakeup fd to *fd*.  When a signal is received, a ``'\0'`` byte is
	written to the fd.  This can be used by a library to wakeup a poll or select
	call, allowing the signal to be fully processed.
	
	The old wakeup fd is returned.  *fd* must be non-blocking.  It is up to the
	library to remove any bytes before calling poll or select again.
	
	When threads are enabled, this function can only be called from the main thread;
	attempting to call it from other threads will cause a :exc:`ValueError`
	exception to be raised.
	
	"""
	pass
	
def siginterrupt(signalnum,flag):
	"""
	Change system call restart behaviour: if *flag* is :const:`False`, system
	calls will be restarted when interrupted by signal *signalnum*, otherwise
	system calls will be interrupted.  Returns nothing.  Availability: Unix (see
	the man page :manpage:`siginterrupt(3)` for further information).
	
	Note that installing a signal handler with :func:`signal` will reset the
	restart behaviour to interruptible by implicitly calling
	:cfunc:`siginterrupt` with a true *flag* value for the given signal.
	
	"""
	pass
	



# AUTO-GENERATED FILE -- DO NOT EDIT


__package__ = None

def crypt(word, salt):
  """ crypt(word, salt) -> string
  word will usually be a user's password. salt is a 2-character string
  which will be used to select one of 4096 variations of DES. The characters
  in salt must be either ".", "/", or an alphanumeric character. Returns
  the hashed password as a string, which will be composed of characters from
  the same alphabet as the salt. """
  return ""




class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class KNS():
    """"""
    def standardAction(self, what, receiver, slot, parent, name = None):
        '''static KAction KNS.standardAction(QString what, QObject receiver, str slot, KActionCollection parent, str name = None)'''
        return KAction()
    class KTranslatable():
        """"""
        def __init__(self):
            '''void KNS.KTranslatable.__init__()'''
        def __init__(self, string):
            '''void KNS.KTranslatable.__init__(QString string)'''
        def __init__(self):
            '''KNS.KTranslatable KNS.KTranslatable.__init__()'''
            return KNS.KTranslatable()
        def isEmpty(self):
            '''bool KNS.KTranslatable.isEmpty()'''
            return bool()
        def isTranslated(self):
            '''bool KNS.KTranslatable.isTranslated()'''
            return bool()
        def stringmap(self):
            '''dict-of-QString-QString KNS.KTranslatable.stringmap()'''
            return dict-of-QString-QString()
        def language(self):
            '''QString KNS.KTranslatable.language()'''
            return QString()
        def languages(self):
            '''QStringList KNS.KTranslatable.languages()'''
            return QStringList()
        def strings(self):
            '''QStringList KNS.KTranslatable.strings()'''
            return QStringList()
        def translated(self, lang):
            '''QString KNS.KTranslatable.translated(QString lang)'''
            return QString()
        def representation(self):
            '''QString KNS.KTranslatable.representation()'''
            return QString()
        def addString(self, lang, string):
            '''void KNS.KTranslatable.addString(QString lang, QString string)'''
    class Author():
        """"""
        def __init__(self):
            '''void KNS.Author.__init__()'''
        def __init__(self, other):
            '''void KNS.Author.__init__(KNS.Author other)'''
        def homepage(self):
            '''QString KNS.Author.homepage()'''
            return QString()
        def setHomepage(self, homepage):
            '''void KNS.Author.setHomepage(QString homepage)'''
        def jabber(self):
            '''QString KNS.Author.jabber()'''
            return QString()
        def setJabber(self, jabber):
            '''void KNS.Author.setJabber(QString jabber)'''
        def email(self):
            '''QString KNS.Author.email()'''
            return QString()
        def setEmail(self, email):
            '''void KNS.Author.setEmail(QString email)'''
        def name(self):
            '''QString KNS.Author.name()'''
            return QString()
        def setName(self, name):
            '''void KNS.Author.setName(QString name)'''
    class Category():
        """"""
        def __init__(self):
            '''void KNS.Category.__init__()'''
        def icon(self):
            '''KUrl KNS.Category.icon()'''
            return KUrl()
        def setIcon(self, icon):
            '''void KNS.Category.setIcon(KUrl icon)'''
        def description(self):
            '''KNS.KTranslatable KNS.Category.description()'''
            return KNS.KTranslatable()
        def setDescription(self, type):
            '''void KNS.Category.setDescription(KNS.KTranslatable type)'''
        def name(self):
            '''KNS.KTranslatable KNS.Category.name()'''
            return KNS.KTranslatable()
        def setName(self, name):
            '''void KNS.Category.setName(KNS.KTranslatable name)'''
        def id(self):
            '''QString KNS.Category.id()'''
            return QString()
        def setId(self, id):
            '''void KNS.Category.setId(QString id)'''
    class Button(KPushButton):
        """"""
        def __init__(self, what, providerList, resourceType, parent):
            '''void KNS.Button.__init__(QString what, QString providerList, QString resourceType, QWidget parent)'''
        def __init__(self, parent):
            '''void KNS.Button.__init__(QWidget parent)'''
        def showDialog(self):
            '''void KNS.Button.showDialog()'''
        dialogFinished = pyqtSignal() # void dialogFinished() - signal
        aboutToShowDialog = pyqtSignal() # void aboutToShowDialog() - signal
        def setButtonText(self, what):
            '''void KNS.Button.setButtonText(QString what)'''
        def setResourceType(self, resourceType):
            '''void KNS.Button.setResourceType(QString resourceType)'''
        def setProviderList(self, providerList):
            '''void KNS.Button.setProviderList(QString providerList)'''
    class Installation():
        """"""
        # Enum KNS.Installation.Scope
        ScopeUser = 0
        ScopeSystem = 0
    
        # Enum KNS.Installation.Policy
        CheckNever = 0
        CheckIfPossible = 0
        CheckAlways = 0
    
        def __init__(self):
            '''void KNS.Installation.__init__()'''
        def customName(self):
            '''bool KNS.Installation.customName()'''
            return bool()
        def scope(self):
            '''KNS.Installation.Scope KNS.Installation.scope()'''
            return KNS.Installation.Scope()
        def signaturePolicy(self):
            '''KNS.Installation.Policy KNS.Installation.signaturePolicy()'''
            return KNS.Installation.Policy()
        def checksumPolicy(self):
            '''KNS.Installation.Policy KNS.Installation.checksumPolicy()'''
            return KNS.Installation.Policy()
        def isRemote(self):
            '''bool KNS.Installation.isRemote()'''
            return bool()
        def absoluteInstallPath(self):
            '''QString KNS.Installation.absoluteInstallPath()'''
            return QString()
        def installPath(self):
            '''QString KNS.Installation.installPath()'''
            return QString()
        def targetDir(self):
            '''QString KNS.Installation.targetDir()'''
            return QString()
        def standardResourceDir(self):
            '''QString KNS.Installation.standardResourceDir()'''
            return QString()
        def uninstallCommand(self):
            '''QString KNS.Installation.uninstallCommand()'''
            return QString()
        def command(self):
            '''QString KNS.Installation.command()'''
            return QString()
        def uncompression(self):
            '''QString KNS.Installation.uncompression()'''
            return QString()
        def setCustomName(self, customname):
            '''void KNS.Installation.setCustomName(bool customname)'''
        def setSignaturePolicy(self, policy):
            '''void KNS.Installation.setSignaturePolicy(KNS.Installation.Policy policy)'''
        def setChecksumPolicy(self, policy):
            '''void KNS.Installation.setChecksumPolicy(KNS.Installation.Policy policy)'''
        def setScope(self, scope):
            '''void KNS.Installation.setScope(KNS.Installation.Scope scope)'''
        def setAbsoluteInstallPath(self, dir):
            '''void KNS.Installation.setAbsoluteInstallPath(QString dir)'''
        def setInstallPath(self, dir):
            '''void KNS.Installation.setInstallPath(QString dir)'''
        def setTargetDir(self, dir):
            '''void KNS.Installation.setTargetDir(QString dir)'''
        def setStandardResourceDir(self, dir):
            '''void KNS.Installation.setStandardResourceDir(QString dir)'''
        def setUninstallCommand(self, command):
            '''void KNS.Installation.setUninstallCommand(QString command)'''
        def setCommand(self, command):
            '''void KNS.Installation.setCommand(QString command)'''
        def setUncompression(self, uncompression):
            '''void KNS.Installation.setUncompression(QString uncompression)'''
    class Engine():
        """"""
        def __init__(self, parent = None):
            '''void KNS.Engine.__init__(QWidget parent = None)'''
        def init(self, config):
            '''bool KNS.Engine.init(QString config)'''
            return bool()
        def uploadDialog(self, file):
            '''void KNS.Engine.uploadDialog(QString file)'''
        def downloadDialog(self):
            '''void KNS.Engine.downloadDialog()'''
        def downloadDialog(self, receiver, slot):
            '''void KNS.Engine.downloadDialog(QObject receiver, str slot)'''
        def upload(self, file):
            '''static KNS.Entry KNS.Engine.upload(QString file)'''
            return KNS.Entry()
        def uploadDialogModal(self, file):
            '''KNS.Entry KNS.Engine.uploadDialogModal(QString file)'''
            return KNS.Entry()
        def download(self):
            '''static list-of-KNS.Entry KNS.Engine.download()'''
            return [KNS.Entry()]
        def downloadDialogModal(self, parent = None):
            '''list-of-KNS.Entry KNS.Engine.downloadDialogModal(QWidget parent = None)'''
            return [KNS.Entry()]
    class Entry():
        """"""
        # Enum KNS.Entry.Source
        Cache = 0
        Online = 0
        Registry = 0
    
        # Enum KNS.Entry.Status
        Invalid = 0
        Downloadable = 0
        Installed = 0
        Updateable = 0
        Deleted = 0
    
        def __init__(self):
            '''void KNS.Entry.__init__()'''
        def __init__(self, other):
            '''void KNS.Entry.__init__(KNS.Entry other)'''
        def idNumber(self):
            '''int KNS.Entry.idNumber()'''
            return int()
        def setIdNumber(self, number):
            '''void KNS.Entry.setIdNumber(int number)'''
        def source(self):
            '''KNS.Entry.Source KNS.Entry.source()'''
            return KNS.Entry.Source()
        def setSource(self, source):
            '''void KNS.Entry.setSource(KNS.Entry.Source source)'''
        def status(self):
            '''KNS.Entry.Status KNS.Entry.status()'''
            return KNS.Entry.Status()
        def setStatus(self, status):
            '''void KNS.Entry.setStatus(KNS.Entry.Status status)'''
        def signature(self):
            '''QString KNS.Entry.signature()'''
            return QString()
        def checksum(self):
            '''QString KNS.Entry.checksum()'''
            return QString()
        def setSignature(self, signature):
            '''void KNS.Entry.setSignature(QString signature)'''
        def setChecksum(self, checksum):
            '''void KNS.Entry.setChecksum(QString checksum)'''
        def downloads(self):
            '''int KNS.Entry.downloads()'''
            return int()
        def setDownloads(self, downloads):
            '''void KNS.Entry.setDownloads(int downloads)'''
        def rating(self):
            '''int KNS.Entry.rating()'''
            return int()
        def setRating(self, rating):
            '''void KNS.Entry.setRating(int rating)'''
        def uninstalledFiles(self):
            '''QStringList KNS.Entry.uninstalledFiles()'''
            return QStringList()
        def installedFiles(self):
            '''QStringList KNS.Entry.installedFiles()'''
            return QStringList()
        def setUnInstalledFiles(self, files):
            '''void KNS.Entry.setUnInstalledFiles(QStringList files)'''
        def setInstalledFiles(self, files):
            '''void KNS.Entry.setInstalledFiles(QStringList files)'''
        def preview(self):
            '''KNS.KTranslatable KNS.Entry.preview()'''
            return KNS.KTranslatable()
        def setPreview(self, url):
            '''void KNS.Entry.setPreview(KNS.KTranslatable url)'''
        def payload(self):
            '''KNS.KTranslatable KNS.Entry.payload()'''
            return KNS.KTranslatable()
        def setPayload(self, url):
            '''void KNS.Entry.setPayload(KNS.KTranslatable url)'''
        def releaseDate(self):
            '''QDate KNS.Entry.releaseDate()'''
            return QDate()
        def setReleaseDate(self, releasedate):
            '''void KNS.Entry.setReleaseDate(QDate releasedate)'''
        def release(self):
            '''int KNS.Entry.release()'''
            return int()
        def setRelease(self, release):
            '''void KNS.Entry.setRelease(int release)'''
        def version(self):
            '''QString KNS.Entry.version()'''
            return QString()
        def setVersion(self, version):
            '''void KNS.Entry.setVersion(QString version)'''
        def summary(self):
            '''KNS.KTranslatable KNS.Entry.summary()'''
            return KNS.KTranslatable()
        def setSummary(self, summary):
            '''void KNS.Entry.setSummary(KNS.KTranslatable summary)'''
        def license(self):
            '''QString KNS.Entry.license()'''
            return QString()
        def setLicense(self, license):
            '''void KNS.Entry.setLicense(QString license)'''
        def author(self):
            '''KNS.Author KNS.Entry.author()'''
            return KNS.Author()
        def setAuthor(self, author):
            '''void KNS.Entry.setAuthor(KNS.Author author)'''
        def category(self):
            '''QString KNS.Entry.category()'''
            return QString()
        def setCategory(self, category):
            '''void KNS.Entry.setCategory(QString category)'''
        def name(self):
            '''KNS.KTranslatable KNS.Entry.name()'''
            return KNS.KTranslatable()
        def setName(self, name):
            '''void KNS.Entry.setName(KNS.KTranslatable name)'''


class KNS3():
    """"""
    def standardActionUpload(self, what, parent, name = None):
        '''static SLOT() KNS3.standardActionUpload(QString what, KActionCollection parent, str name = None)'''
        return SLOT()()
    def standardActionUpload(self, what, parent, name = None):
        '''static callable KNS3.standardActionUpload(QString what, KActionCollection parent, str name = None)'''
        return callable()
    def standardAction(self, what, parent, name = None):
        '''static SLOT() KNS3.standardAction(QString what, KActionCollection parent, str name = None)'''
        return SLOT()()
    def standardAction(self, what, parent, name = None):
        '''static callable KNS3.standardAction(QString what, KActionCollection parent, str name = None)'''
        return callable()
    class DownloadManager(QObject):
        """"""
        # Enum KNS3.DownloadManager.SortOrder
        Newest = 0
        Alphabetical = 0
        Rating = 0
        Downloads = 0
    
        def __init__(self, parent = None):
            '''void KNS3.DownloadManager.__init__(QObject parent = None)'''
        def __init__(self, configFile, parent = None):
            '''void KNS3.DownloadManager.__init__(QString configFile, QObject parent = None)'''
        def uninstallEntry(self, entry):
            '''void KNS3.DownloadManager.uninstallEntry(KNS3.Entry entry)'''
        entryStatusChanged = pyqtSignal() # void entryStatusChanged(const KNS3::Entryamp;) - signal
        searchResult = pyqtSignal() # void searchResult(const KNS3::Entry::Listamp;) - signal
        def setSearchOrder(self, order):
            '''void KNS3.DownloadManager.setSearchOrder(KNS3.DownloadManager.SortOrder order)'''
        def setSearchTerm(self, searchTerm):
            '''void KNS3.DownloadManager.setSearchTerm(QString searchTerm)'''
        def installEntry(self, entry):
            '''void KNS3.DownloadManager.installEntry(KNS3.Entry entry)'''
        def checkForUpdates(self):
            '''void KNS3.DownloadManager.checkForUpdates()'''
        def search(self, page = 0, pageSize = 100):
            '''void KNS3.DownloadManager.search(int page = 0, int pageSize = 100)'''
    class UploadDialog(KDialog):
        """"""
        def __init__(self, parent = None):
            '''void KNS3.UploadDialog.__init__(QWidget parent = None)'''
        def __init__(self, configFile, parent = None):
            '''void KNS3.UploadDialog.__init__(QString configFile, QWidget parent = None)'''
        def setPreviewImageFile(self, number, file):
            '''void KNS3.UploadDialog.setPreviewImageFile(int number, KUrl file)'''
        def setPriceEnabled(self, enabled):
            '''void KNS3.UploadDialog.setPriceEnabled(bool enabled)'''
        def selectCategory(self, category):
            '''void KNS3.UploadDialog.selectCategory(QString category)'''
        def setPriceReason(self, reason):
            '''void KNS3.UploadDialog.setPriceReason(QString reason)'''
        def setPrice(self, price):
            '''void KNS3.UploadDialog.setPrice(float price)'''
        def setChangelog(self, changelog):
            '''void KNS3.UploadDialog.setChangelog(QString changelog)'''
        def setDescription(self, description):
            '''void KNS3.UploadDialog.setDescription(QString description)'''
        def setVersion(self, version):
            '''void KNS3.UploadDialog.setVersion(QString version)'''
        def accept(self):
            '''void KNS3.UploadDialog.accept()'''
        def setUploadName(self, name):
            '''void KNS3.UploadDialog.setUploadName(QString name)'''
        def setUploadFile(self, payloadFile):
            '''void KNS3.UploadDialog.setUploadFile(KUrl payloadFile)'''
    class Button(KPushButton):
        """"""
        def __init__(self, text, configFile, parent):
            '''void KNS3.Button.__init__(QString text, QString configFile, QWidget parent)'''
        def __init__(self, parent):
            '''void KNS3.Button.__init__(QWidget parent)'''
        def showDialog(self):
            '''void KNS3.Button.showDialog()'''
        dialogFinished = pyqtSignal() # void dialogFinished(const KNS3::Entry::Listamp;) - signal
        aboutToShowDialog = pyqtSignal() # void aboutToShowDialog() - signal
        def setButtonText(self, text):
            '''void KNS3.Button.setButtonText(QString text)'''
        def setConfigFile(self, configFile):
            '''void KNS3.Button.setConfigFile(QString configFile)'''
    class Entry():
        """"""
        # Enum KNS3.Entry.Status
        Invalid = 0
        Downloadable = 0
        Installed = 0
        Updateable = 0
        Deleted = 0
        Installing = 0
        Updating = 0
    
        def __init__(self, other):
            '''void KNS3.Entry.__init__(KNS3.Entry other)'''
        def providerId(self):
            '''QString KNS3.Entry.providerId()'''
            return QString()
        def id(self):
            '''QString KNS3.Entry.id()'''
            return QString()
        def version(self):
            '''QString KNS3.Entry.version()'''
            return QString()
        def summary(self):
            '''QString KNS3.Entry.summary()'''
            return QString()
        def license(self):
            '''QString KNS3.Entry.license()'''
            return QString()
        def status(self):
            '''KNS3.Entry.Status KNS3.Entry.status()'''
            return KNS3.Entry.Status()
        def uninstalledFiles(self):
            '''QStringList KNS3.Entry.uninstalledFiles()'''
            return QStringList()
        def installedFiles(self):
            '''QStringList KNS3.Entry.installedFiles()'''
            return QStringList()
        def category(self):
            '''QString KNS3.Entry.category()'''
            return QString()
        def name(self):
            '''QString KNS3.Entry.name()'''
            return QString()
    class DownloadWidget(QWidget):
        """"""
        def __init__(self, parent = None):
            '''void KNS3.DownloadWidget.__init__(QWidget parent = None)'''
        def __init__(self, configFile, parent = None):
            '''void KNS3.DownloadWidget.__init__(QString configFile, QWidget parent = None)'''
        def installedEntries(self):
            '''list-of-KNS3.Entry KNS3.DownloadWidget.installedEntries()'''
            return [KNS3.Entry()]
        def changedEntries(self):
            '''list-of-KNS3.Entry KNS3.DownloadWidget.changedEntries()'''
            return [KNS3.Entry()]
    class DownloadDialog(KDialog):
        """"""
        def __init__(self, parent = None):
            '''void KNS3.DownloadDialog.__init__(QWidget parent = None)'''
        def __init__(self, configFile, parent = None):
            '''void KNS3.DownloadDialog.__init__(QString configFile, QWidget parent = None)'''
        def installedEntries(self):
            '''list-of-KNS3.Entry KNS3.DownloadDialog.installedEntries()'''
            return [KNS3.Entry()]
        def changedEntries(self):
            '''list-of-KNS3.Entry KNS3.DownloadDialog.changedEntries()'''
            return [KNS3.Entry()]





def func(foo, bar, *args, **kwargs):
    pass

    
mydict = dict()
mylist = list(mydict)

class c():
    attr = 5

another_comprehended_list = [item.attr for item in [c(), c(), c()]]
    
comprehended_list = [x for x in [1, 2, 3] if x in ('a')]
print(x)
    
def func(**kwargs):
    for item in kwargs.iterkeys():
        print(item)
    return kwargs

def yieldTest():
    yield "foo"
    
def my_func():
    my_var_04 = 5
    my_var_01 = 1
    my_var_07 = 12
    my_var_07 = 12
    my_var_07 = 12
    more_vars = 2
    my_var_02 = 2
    my_var_03 = 3

class cls():
    def myfunc(self):
        some_var = my_func
    
    def another(self):
        print(self)

new_threads = cls()

try:
    known_threads = {line.strip() for line  in ["foo"] if line.strip()}
except IOError:
    pass
    known_threads = set()

# Remove threads already in the cache so we can write the new ones only.
new_threads = new_threads - known_threads
        
import os

def ASDF(arg, arg2):
    arg = arg2
    print(arg2)
print(ASDF())

a = a and a
a = a or b

class some_class(foo, bar):
    def __init__(self):
        pass
    
    attr1 = 3
    attr2 = 5
    attr3 = 'str'

argarg = 2

some_instance = some_class()
some_instance.attr1
some_instance.attr2
some_instance.some_method().foobar
some_instance.some_method(some_arg, some_arg2).second_attribute
some_instance \
		.   attr1 \
		.funcfunc(argarg, arg2arg) \
		.foo

#comment
"""
multiline comment
foo
bar
"""
 
import sys
import random

import PyQt4.QtCore

import bisect
bisect.bisect_right()

def returns_int(param):
    return 5

def returns_str(param):
    return 'str'

def returns_list(param): return [];

foo = returns_list()

bar = 'test'
foo = returns_int()
s = returns_str()
l = returns_list()

def simple_func(foo):
	""" usage comment, bla, param:foo"""
	pass

copied = simple_func

def function(foo):
	""" docstring
	more
	more more
	>>> test
	>>> test
	"""
	return foo

async def fonc(x, y, z):
    a = await z

try:
    pass
except Exception as e:
    print(e)

def func(foo, bar, baz, bang, foobang, foobar, foobazbar, foobazbarbang):
    return foobang
    
    import asynchat
    obj = asynchat.async_chat()
    obj.collect_incoming_data()
    import _winreg
    _winreg.CreateKey()
    import binhex
    binhex.hexbin()
    
    if foobazbar < 5:
        pass

func(sys)
simple_func()

def func_without_param():
    pass
    return [(lambda foo: foo) for fdlksh in [1, 2, 3]]

func_without_param()

def another_function(param):
    return [3 for x in param]

a = 5

bar = a == a
a != a
a < a
a <= a
a > a
a < a < a
a >= a
a is a
a is not a
a not in a
a in a

a = a + 1
a = a - 1
a = a * 1
a = a / 1
a = a // 1
a = a % 1
a = a ^ 1
a = a & 1
a = a | 1
a = a ** 1
a = a >> 1
a = a << 1
a = a @ 1

a = not a
a = +a
a = -a
a = ~a

a = b[1:2:3][2]
extended = a[1:2, 2:3]

i += 3
i += j

3 if 5 < 7 else 4

from random import random

random(foo=3)

a = lambda x: x**2

@staticmethod
@classmethod
def genfunc():
    yield foo

for target1, target2 in some_dict.iteritems():
    print(target1, target2)

pi = 3.1415

foo = 1, 2
bar = (1, 2)

with open('f') as foo:
    pass

global IMAGLOBALVARIABLE
IMAGLOBALVARIABLE = 0
try:
    a = 3 / 0
except ZeroDivisionError as err:
    raise ValueError
else:
    do_something()
finally:
    BAM

if 3 and 5:
    pass

for i in xrange(20):
    pass

while True:
    break
    continue

del foo

import random
random.random(3, 5)

somelist = [1, 2, 3, 4, 5]
somedict = { 'key1' : 'value1', key2: value2 }

somelist[...]
somelist[1:]
somelist[:20]
somelist[1:20]
somelist[1:20:2]

class bar(parent):
    pass

if foo in bar and 3 < 5:
    pass

a = [x*2 for x in xrange(20)]

variable.variable2.variable3 = 15
def function(param1, param2, param3, *paramstar, **paramdstar):
    pass
    return param1 * param2

assert False
if not 3:
    pass

if 3 * 5 == 7:
    pass



# AUTO-GENERATED FILE -- DO NOT EDIT

""" This module provides access to the Unix shadow password database.
It is available on various Unix versions.

Shadow password database entries are reported as 9-tuples of type struct_spwd,
containing the following items from the password database (see `<shadow.h>'):
sp_namp, sp_pwdp, sp_lstchg, sp_min, sp_max, sp_warn, sp_inact, sp_expire, sp_flag.
The sp_namp and sp_pwdp are strings, the rest are integers.
An exception is raised if the entry asked for cannot be found.
You have to be root to be able to use this module. """

__package__ = None

def getspall():
  """ getspall() -> list_of_entries
  Return a list of all available shadow password database entries, in arbitrary order.
  See spwd.__doc__ for more on shadow password database entries. """
  return []

def getspnam(name):
  """ getspnam(name) -> (sp_namp, sp_pwdp, sp_lstchg, sp_min, sp_max,
                      sp_warn, sp_inact, sp_expire, sp_flag)
  Return the shadow password database entry for the given user name.
  See spwd.__doc__ for more on shadow password database entries. """
  return (None, None, None, None, None, None, None, None, None)

class struct_spwd(object):
  """ spwd.struct_spwd: Results from getsp*() routines.
  
  This object may be accessed either as a 9-tuple of
    (sp_nam,sp_pwd,sp_lstchg,sp_min,sp_max,sp_warn,sp_inact,sp_expire,sp_flag)
  or via the object attributes as named in the above tuple. """

  n_fields = 9
  n_sequence_fields = 9
  n_unnamed_fields = 0
  sp_expire = None
  sp_flag = None
  sp_inact = None
  sp_lstchg = None
  sp_max = None
  sp_min = None
  sp_nam = None
  sp_pwd = None
  sp_warn = None




#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
"""
Built-in Functions
==================

The Python interpreter has a number of functions built into it that are always
available.  They are listed here in alphabetical order.

===================  =================  ==================  =================  ====================
..                ..              Built-in Functions  ..              ..
===================  =================  ==================  =================  ====================
:func:`abs`          :func:`divmod`     :func:`input`       :func:`open`       :func:`staticmethod`
:func:`all`          :func:`enumerate`  :func:`int`         :func:`ord`        :func:`str`
:func:`any`          :func:`eval`       :func:`isinstance`  :func:`pow`        :func:`sum`
:func:`basestring`   :func:`execfile`   :func:`issubclass`  :func:`print`      :func:`super`
:func:`bin`          :func:`file`       :func:`iter`        :func:`property`   :func:`tuple`
:func:`bool`         :func:`filter`     :func:`len`         :func:`range`      :func:`type`
:func:`bytearray`    :func:`float`      :func:`list`        :func:`raw_input`  :func:`unichr`
:func:`callable`     :func:`format`     :func:`locals`      :func:`reduce`     :func:`unicode`
:func:`chr`          :func:`frozenset`  :func:`long`        :func:`reload`     :func:`vars`
:func:`classmethod`  :func:`getattr`    :func:`map`         :func:`repr`       :func:`xrange`
:func:`cmp`          :func:`globals`    :func:`max`         :func:`reversed`   :func:`zip`
:func:`compile`      :func:`hasattr`    :func:`memoryview`  :func:`round`      :func:`__import__`
:func:`complex`      :func:`hash`       :func:`min`         :func:`set`        :func:`apply`
:func:`delattr`      :func:`help`       :func:`next`        :func:`setattr`    :func:`buffer`
:func:`dict`         :func:`hex`        :func:`object`      :func:`slice`      :func:`coerce`
:func:`dir`          :func:`id`         :func:`oct`         :func:`sorted`     :func:`intern`
===================  =================  ==================  =================  ====================

"""
def abs(x):
	"""
	Return the absolute value of a number.  The argument may be a plain or long
	integer or a floating point number.  If the argument is a complex number, its
	magnitude is returned.
	
	
	"""
	pass
	
def all(iterable):
	"""
	Return True if all elements of the *iterable* are true (or if the iterable
	is empty).  Equivalent to::
	
	def all(iterable):
	for element in iterable:
	if not element:
	return False
	return True
	
	"""
	pass
	
def any(iterable):
	"""
	Return True if any element of the *iterable* is true.  If the iterable
	is empty, return False.  Equivalent to::
	
	def any(iterable):
	for element in iterable:
	if element:
	return True
	return False
	
	"""
	pass
	
def basestring():
	"""
	This abstract type is the superclass for :class:`str` and :class:`unicode`. It
	cannot be called or instantiated, but it can be used to test whether an object
	is an instance of :class:`str` or :class:`unicode`. ``isinstance(obj,
	basestring)`` is equivalent to ``isinstance(obj, (str, unicode))``.
	
	"""
	pass
	
def bin(x):
	"""
	Convert an integer number to a binary string. The result is a valid Python
	expression.  If *x* is not a Python :class:`int` object, it has to define an
	:meth:`__index__` method that returns an integer.
	
	"""
	pass
	
def bool(x):
	"""
	Convert a value to a Boolean, using the standard truth testing procedure.  If
	*x* is false or omitted, this returns :const:`False`; otherwise it returns
	:const:`True`. :class:`bool` is also a class, which is a subclass of
	:class:`int`. Class :class:`bool` cannot be subclassed further.  Its only
	instances are :const:`False` and :const:`True`.
	
	"""
	pass
	
def bytearray(source,encoding,errors):
	"""
	Return a new array of bytes.  The :class:`bytearray` type is a mutable
	sequence of integers in the range 0 <= x < 256.  It has most of the usual
	methods of mutable sequences, described in :ref:`typesseq-mutable`, as well
	as most methods that the :class:`str` type has, see :ref:`string-methods`.
	
	The optional *source* parameter can be used to initialize the array in a few
	different ways:
	
	* If it is a *string*, you must also give the *encoding* (and optionally,
	*errors*) parameters; :func:`bytearray` then converts the string to
	bytes using :meth:`str.encode`.
	
	* If it is an *integer*, the array will have that size and will be
	initialized with null bytes.
	
	* If it is an object conforming to the *buffer* interface, a read-only buffer
	of the object will be used to initialize the bytes array.
	
	* If it is an *iterable*, it must be an iterable of integers in the range
	``0 <= x < 256``, which are used as the initial contents of the array.
	
	Without an argument, an array of size 0 is created.
	
	
	"""
	pass
	
def callable(object):
	"""
	Return :const:`True` if the *object* argument appears callable,
	:const:`False` if not.  If this
	returns true, it is still possible that a call fails, but if it is false,
	calling *object* will never succeed.  Note that classes are callable (calling a
	class returns a new instance); class instances are callable if they have a
	:meth:`__call__` method.
	
	
	"""
	pass
	
def chr(i):
	"""
	Return a string of one character whose ASCII code is the integer *i*.  For
	example, ``chr(97)`` returns the string ``'a'``. This is the inverse of
	:func:`ord`.  The argument must be in the range [0..255], inclusive;
	:exc:`ValueError` will be raised if *i* is outside that range. See
	also :func:`unichr`.
	
	
	"""
	pass
	
def _classmethod(function):
	"""
	Return a class method for *function*.
	
	A class method receives the class as implicit first argument, just like an
	instance method receives the instance. To declare a class method, use this
	idiom::
	
	class C:
	@classmethod
	def f(cls, arg1, arg2, more): more
	
	The ``@classmethod`` form is a function :term:`decorator` -- see the description
	of function definitions in :ref:`function` for details.
	
	It can be called either on the class (such as ``C.f()``) or on an instance (such
	as ``C().f()``).  The instance is ignored except for its class. If a class
	method is called for a derived class, the derived class object is passed as the
	implied first argument.
	
	Class methods are different than C++ or Java static methods. If you want those,
	see :func:`staticmethod` in this section.
	
	For more information on class methods, consult the documentation on the standard
	type hierarchy in :ref:`types`.
	
	"""
	pass
	
def cmp(x,y):
	"""
	Compare the two objects *x* and *y* and return an integer according to the
	outcome.  The return value is negative if ``x < y``, zero if ``x == y`` and
	strictly positive if ``x > y``.
	
	
	"""
	pass
	
def compile(source,filename,mode,flags,dont_inherit):
	"""
	Compile the *source* into a code or AST object.  Code objects can be executed
	by an :keyword:`exec` statement or evaluated by a call to :func:`eval`.
	*source* can either be a string or an AST object.  Refer to the :mod:`ast`
	module documentation for information on how to work with AST objects.
	
	The *filename* argument should give the file from which the code was read;
	pass some recognizable value if it wasn't read from a file (``'<string>'`` is
	commonly used).
	
	The *mode* argument specifies what kind of code must be compiled; it can be
	``'exec'`` if *source* consists of a sequence of statements, ``'eval'`` if it
	consists of a single expression, or ``'single'`` if it consists of a single
	interactive statement (in the latter case, expression statements that
	evaluate to something other than ``None`` will be printed).
	
	The optional arguments *flags* and *dont_inherit* control which future
	statements (see :pep:`236`) affect the compilation of *source*.  If neither
	is present (or both are zero) the code is compiled with those future
	statements that are in effect in the code that is calling compile.  If the
	*flags* argument is given and *dont_inherit* is not (or is zero) then the
	future statements specified by the *flags* argument are used in addition to
	those that would be used anyway. If *dont_inherit* is a non-zero integer then
	the *flags* argument is it -- the future statements in effect around the call
	to compile are ignored.
	
	Future statements are specified by bits which can be bitwise ORed together to
	specify multiple statements.  The bitfield required to specify a given feature
	can be found as the :attr:`compiler_flag` attribute on the :class:`_Feature`
	instance in the :mod:`__future__` module.
	
	This function raises :exc:`SyntaxError` if the compiled source is invalid,
	and :exc:`TypeError` if the source contains null bytes.
	
	"""
	pass
	
def complex(real,imag):
	"""
	Create a complex number with the value *real* + *imag*\*j or convert a string or
	number to a complex number.  If the first parameter is a string, it will be
	interpreted as a complex number and the function must be called without a second
	parameter.  The second parameter can never be a string. Each argument may be any
	numeric type (including complex). If *imag* is omitted, it defaults to zero and
	the function serves as a numeric conversion function like :func:`int`,
	:func:`long` and :func:`float`.  If both arguments are omitted, returns ``0j``.
	
	The complex type is described in :ref:`typesnumeric`.
	
	
	"""
	pass
	
def delattr(object,name):
	"""
	This is a relative of :func:`setattr`.  The arguments are an object and a
	string.  The string must be the name of one of the object's attributes.  The
	function deletes the named attribute, provided the object allows it.  For
	example, ``delattr(x, 'foobar')`` is equivalent to ``del x.foobar``.
	
	
	"""
	pass
	
def dict(arg):
	""":noindex:
	
	Create a new data dictionary, optionally with items taken from *arg*.
	The dictionary type is described in :ref:`typesmapping`.
	
	For other containers see the built in :class:`list`, :class:`set`, and
	:class:`tuple` classes, and the :mod:`collections` module.
	
	
	"""
	pass
	
def dir(object):
	"""
	Without arguments, return the list of names in the current local scope.  With an
	argument, attempt to return a list of valid attributes for that object.
	
	If the object has a method named :meth:`__dir__`, this method will be called and
	must return the list of attributes. This allows objects that implement a custom
	:func:`__getattr__` or :func:`__getattribute__` function to customize the way
	:func:`dir` reports their attributes.
	
	If the object does not provide :meth:`__dir__`, the function tries its best to
	gather information from the object's :attr:`__dict__` attribute, if defined, and
	from its type object.  The resulting list is not necessarily complete, and may
	be inaccurate when the object has a custom :func:`__getattr__`.
	
	The default :func:`dir` mechanism behaves differently with different types of
	objects, as it attempts to produce the most relevant, rather than complete,
	information:
	
	* If the object is a module object, the list contains the names of the module's
	attributes.
	
	* If the object is a type or class object, the list contains the names of its
	attributes, and recursively of the attributes of its bases.
	
	* Otherwise, the list contains the object's attributes' names, the names of its
	class's attributes, and recursively of the attributes of its class's base
	classes.
	
	The resulting list is sorted alphabetically.  For example:
	
	>>> import struct
	>>> dir()   # doctest: +SKIP
	['__builtins__', '__doc__', '__name__', 'struct']
	>>> dir(struct)   # doctest: +NORMALIZE_WHITESPACE
	['Struct', '__builtins__', '__doc__', '__file__', '__name__',
	'__package__', '_clearcache', 'calcsize', 'error', 'pack', 'pack_into',
	'unpack', 'unpack_from']
	>>> class Foo(object):
	more     def __dir__(self):
	more         return ["kan", "ga", "roo"]
	more
	>>> f = Foo()
	>>> dir(f)
	['ga', 'kan', 'roo']
	
	"""
	pass
	
def divmod(a,b):
	"""
	Take two (non complex) numbers as arguments and return a pair of numbers
	consisting of their quotient and remainder when using long division.  With mixed
	operand types, the rules for binary arithmetic operators apply.  For plain and
	long integers, the result is the same as ``(a // b, a % b)``. For floating point
	numbers the result is ``(q, a % b)``, where *q* is usually ``math.floor(a / b)``
	but may be 1 less than that.  In any case ``q * b + a % b`` is very close to
	*a*, if ``a % b`` is non-zero it has the same sign as *b*, and ``0 <= abs(a % b)
	< abs(b)``.
	
	"""
	pass
	
def enumerate(sequence,start=0):
	"""
	Return an enumerate object. *sequence* must be a sequence, an
	:term:`iterator`, or some other object which supports iteration.  The
	:meth:`!next` method of the iterator returned by :func:`enumerate` returns a
	tuple containing a count (from *start* which defaults to 0) and the
	corresponding value obtained from iterating over *iterable*.
	:func:`enumerate` is useful for obtaining an indexed series: ``(0, seq[0])``,
	``(1, seq[1])``, ``(2, seq[2])``, more. For example:
	
	>>> for i, season in enumerate(['Spring', 'Summer', 'Fall', 'Winter']):
	more     print i, season
	0 Spring
	1 Summer
	2 Fall
	3 Winter
	
	"""
	pass
	
def eval(expression,globals,locals):
	"""
	The arguments are a string and optional globals and locals.  If provided,
	*globals* must be a dictionary.  If provided, *locals* can be any mapping
	object.
	
	"""
	pass
	
def execfile(filename,globals,locals):
	"""
	This function is similar to the :keyword:`exec` statement, but parses a file
	instead of a string.  It is different from the :keyword:`import` statement in
	that it does not use the module administration --- it reads the file
	unconditionally and does not create a new module. [#]_
	
	The arguments are a file name and two optional dictionaries.  The file is parsed
	and evaluated as a sequence of Python statements (similarly to a module) using
	the *globals* and *locals* dictionaries as global and local namespace. If
	provided, *locals* can be any mapping object.
	
	"""
	pass
	
def file(filename,mode,bufsize):
	"""
	Constructor function for the :class:`file` type, described further in section
	:ref:`bltin-file-objects`.  The constructor's arguments are the same as those
	of the :func:`open` built-in function described below.
	
	When opening a file, it's preferable to use :func:`open` instead of  invoking
	this constructor directly.  :class:`file` is more suited to type testing (for
	example, writing ``isinstance(f, file)``).
	
	"""
	pass
	
def filter(function,iterable):
	"""
	Construct a list from those elements of *iterable* for which *function* returns
	true.  *iterable* may be either a sequence, a container which supports
	iteration, or an iterator.  If *iterable* is a string or a tuple, the result
	also has that type; otherwise it is always a list.  If *function* is ``None``,
	the identity function is assumed, that is, all elements of *iterable* that are
	false are removed.
	
	Note that ``filter(function, iterable)`` is equivalent to ``[item for item in
	iterable if function(item)]`` if function is not ``None`` and ``[item for item
	in iterable if item]`` if function is ``None``.
	
	See :func:`itertools.ifilter` and :func:`itertools.ifilterfalse` for iterator
	versions of this function, including a variation that filters for elements
	where the *function* returns false.
	
	
	"""
	pass
	
def float(x):
	"""
	Convert a string or a number to floating point.  If the argument is a string, it
	must contain a possibly signed decimal or floating point number, possibly
	embedded in whitespace. The argument may also be [+|-]nan or [+|-]inf.
	Otherwise, the argument may be a plain or long integer
	or a floating point number, and a floating point number with the same value
	(within Python's floating point precision) is returned.  If no argument is
	given, returns ``0.0``.
	
	"""
	pass
	
def format(value,format_spec):
	"""
	"""
	pass
	
def frozenset(iterable):
	""":noindex:
	
	Return a frozenset object, optionally with elements taken from *iterable*.
	The frozenset type is described in :ref:`types-set`.
	
	For other containers see the built in :class:`dict`, :class:`list`, and
	:class:`tuple` classes, and the :mod:`collections` module.
	
	"""
	pass
	
def getattr(object,name,default):
	"""
	Return the value of the named attribute of *object*.  *name* must be a string.
	If the string is the name of one of the object's attributes, the result is the
	value of that attribute.  For example, ``getattr(x, 'foobar')`` is equivalent to
	``x.foobar``.  If the named attribute does not exist, *default* is returned if
	provided, otherwise :exc:`AttributeError` is raised.
	
	
	"""
	pass
	
def globals():
	"""
	Return a dictionary representing the current global symbol table. This is always
	the dictionary of the current module (inside a function or method, this is the
	module where it is defined, not the module from which it is called).
	
	
	"""
	pass
	
def hasattr(object,name):
	"""
	The arguments are an object and a string.  The result is ``True`` if the string
	is the name of one of the object's attributes, ``False`` if not. (This is
	implemented by calling ``getattr(object, name)`` and seeing whether it raises an
	exception or not.)
	
	
	"""
	pass
	
def hash(object):
	"""
	Return the hash value of the object (if it has one).  Hash values are integers.
	They are used to quickly compare dictionary keys during a dictionary lookup.
	Numeric values that compare equal have the same hash value (even if they are of
	different types, as is the case for 1 and 1.0).
	
	
	"""
	pass
	
def help(object):
	"""
	Invoke the built-in help system.  (This function is intended for interactive
	use.)  If no argument is given, the interactive help system starts on the
	interpreter console.  If the argument is a string, then the string is looked up
	as the name of a module, function, class, method, keyword, or documentation
	topic, and a help page is printed on the console.  If the argument is any other
	kind of object, a help page on the object is generated.
	
	This function is added to the built-in namespace by the :mod:`site` module.
	
	"""
	pass
	
def hex(x):
	"""
	Convert an integer number (of any size) to a hexadecimal string. The result is a
	valid Python expression.
	
	"""
	pass
	
def id(object):
	"""
	Return the "identity" of an object.  This is an integer (or long integer) which
	is guaranteed to be unique and constant for this object during its lifetime.
	Two objects with non-overlapping lifetimes may have the same :func:`id`
	value.
	
	"""
	pass
	
def input(prompt):
	"""
	Equivalent to ``eval(raw_input(prompt))``.
	
	"""
	pass
	
def int(x,base):
	"""
	Convert a string or number to a plain integer.  If the argument is a string,
	it must contain a possibly signed decimal number representable as a Python
	integer, possibly embedded in whitespace.  The *base* parameter gives the
	base for the conversion (which is 10 by default) and may be any integer in
	the range [2, 36], or zero.  If *base* is zero, the proper radix is
	determined based on the contents of string; the interpretation is the same as
	for integer literals.  (See :ref:`numbers`.)  If *base* is specified and *x*
	is not a string, :exc:`TypeError` is raised. Otherwise, the argument may be a
	plain or long integer or a floating point number.  Conversion of floating
	point numbers to integers truncates (towards zero).  If the argument is
	outside the integer range a long object will be returned instead.  If no
	arguments are given, returns ``0``.
	
	The integer type is described in :ref:`typesnumeric`.
	
	
	"""
	pass
	
def isinstance(object,_classinfo):
	"""
	Return true if the *object* argument is an instance of the *classinfo* argument,
	or of a (direct or indirect) subclass thereof.  Also return true if *classinfo*
	is a type object (new-style class) and *object* is an object of that type or of
	a (direct or indirect) subclass thereof.  If *object* is not a class instance or
	an object of the given type, the function always returns false.  If *classinfo*
	is neither a class object nor a type object, it may be a tuple of class or type
	objects, or may recursively contain other such tuples (other sequence types are
	not accepted).  If *classinfo* is not a class, type, or tuple of classes, types,
	and such tuples, a :exc:`TypeError` exception is raised.
	
	"""
	pass
	
def issub_class(_class,_classinfo):
	"""
	Return true if *class* is a subclass (direct or indirect) of *classinfo*.  A
	class is considered a subclass of itself. *classinfo* may be a tuple of class
	objects, in which case every entry in *classinfo* will be checked. In any other
	case, a :exc:`TypeError` exception is raised.
	
	"""
	pass
	
def iter(o,sentinel):
	"""
	Return an :term:`iterator` object.  The first argument is interpreted very differently
	depending on the presence of the second argument. Without a second argument, *o*
	must be a collection object which supports the iteration protocol (the
	:meth:`__iter__` method), or it must support the sequence protocol (the
	:meth:`__getitem__` method with integer arguments starting at ``0``).  If it
	does not support either of those protocols, :exc:`TypeError` is raised. If the
	second argument, *sentinel*, is given, then *o* must be a callable object.  The
	iterator created in this case will call *o* with no arguments for each call to
	its :meth:`~iterator.next` method; if the value returned is equal to *sentinel*,
	:exc:`StopIteration` will be raised, otherwise the value will be returned.
	
	One useful application of the second form of :func:`iter` is to read lines of
	a file until a certain line is reached.  The following example reads a file
	until ``"STOP"`` is reached: ::
	
	with open("mydata.txt") as fp:
	for line in iter(fp.readline, "STOP"):
	process_line(line)
	
	"""
	pass
	
def len(s):
	"""
	Return the length (the number of items) of an object.  The argument may be a
	sequence (string, tuple or list) or a mapping (dictionary).
	
	
	"""
	pass
	
def list(iterable):
	"""
	Return a list whose items are the same and in the same order as *iterable*'s
	items.  *iterable* may be either a sequence, a container that supports
	iteration, or an iterator object.  If *iterable* is already a list, a copy is
	made and returned, similar to ``iterable[:]``.  For instance, ``list('abc')``
	returns ``['a', 'b', 'c']`` and ``list( (1, 2, 3) )`` returns ``[1, 2, 3]``.  If
	no argument is given, returns a new empty list, ``[]``.
	
	:class:`list` is a mutable sequence type, as documented in
	:ref:`typesseq`. For other containers see the built in :class:`dict`,
	:class:`set`, and :class:`tuple` classes, and the :mod:`collections` module.
	
	
	"""
	pass
	
def locals():
	"""
	Update and return a dictionary representing the current local symbol table.
	Free variables are returned by :func:`locals` when it is called in function
	blocks, but not in class blocks.
	
	"""
	pass
	
def long(x,base):
	"""
	Convert a string or number to a long integer.  If the argument is a string, it
	must contain a possibly signed number of arbitrary size, possibly embedded in
	whitespace. The *base* argument is interpreted in the same way as for
	:func:`int`, and may only be given when *x* is a string. Otherwise, the argument
	may be a plain or long integer or a floating point number, and a long integer
	with the same value is returned.    Conversion of floating point numbers to
	integers truncates (towards zero).  If no arguments are given, returns ``0L``.
	
	The long type is described in :ref:`typesnumeric`.
	
	
	"""
	pass
	
def map(function,iterable,more):
	"""
	Apply *function* to every item of *iterable* and return a list of the results.
	If additional *iterable* arguments are passed, *function* must take that many
	arguments and is applied to the items from all iterables in parallel.  If one
	iterable is shorter than another it is assumed to be extended with ``None``
	items.  If *function* is ``None``, the identity function is assumed; if there
	are multiple arguments, :func:`map` returns a list consisting of tuples
	containing the corresponding items from all iterables (a kind of transpose
	operation).  The *iterable* arguments may be a sequence  or any iterable object;
	the result is always a list.
	
	
	"""
	pass
	
def max(iterable,argsmorekey):
	"""
	With a single argument *iterable*, return the largest item of a non-empty
	iterable (such as a string, tuple or list).  With more than one argument, return
	the largest of the arguments.
	
	The optional *key* argument specifies a one-argument ordering function like that
	used for :meth:`list.sort`.  The *key* argument, if supplied, must be in keyword
	form (for example, ``max(a,b,c,key=func)``).
	
	"""
	pass
	
def memoryview(obj):
	""":noindex:
	
	Return a "memory view" object created from the given argument.  See
	:ref:`typememoryview` for more information.
	
	
	"""
	pass
	
def min(iterable,argsmorekey):
	"""
	With a single argument *iterable*, return the smallest item of a non-empty
	iterable (such as a string, tuple or list).  With more than one argument, return
	the smallest of the arguments.
	
	The optional *key* argument specifies a one-argument ordering function like that
	used for :meth:`list.sort`.  The *key* argument, if supplied, must be in keyword
	form (for example, ``min(a,b,c,key=func)``).
	
	"""
	pass
	
def next(iterator,default):
	"""
	Retrieve the next item from the *iterator* by calling its
	:meth:`~iterator.next` method.  If *default* is given, it is returned if the
	iterator is exhausted, otherwise :exc:`StopIteration` is raised.
	
	"""
	pass
	
def object():
	"""
	Return a new featureless object.  :class:`object` is a base for all new style
	classes.  It has the methods that are common to all instances of new style
	classes.
	
	"""
	pass
	
def oct(x):
	"""
	Convert an integer number (of any size) to an octal string.  The result is a
	valid Python expression.
	
	"""
	pass
	
def open(filename,mode,bufsize):
	"""
	Open a file, returning an object of the :class:`file` type described in
	section :ref:`bltin-file-objects`.  If the file cannot be opened,
	:exc:`IOError` is raised.  When opening a file, it's preferable to use
	:func:`open` instead of invoking the :class:`file` constructor directly.
	
	The first two arguments are the same as for ``stdio``'s :cfunc:`fopen`:
	*filename* is the file name to be opened, and *mode* is a string indicating how
	the file is to be opened.
	
	The most commonly-used values of *mode* are ``'r'`` for reading, ``'w'`` for
	writing (truncating the file if it already exists), and ``'a'`` for appending
	(which on *some* Unix systems means that *all* writes append to the end of the
	file regardless of the current seek position).  If *mode* is omitted, it
	defaults to ``'r'``.  The default is to use text mode, which may convert
	``'\n'`` characters to a platform-specific representation on writing and back
	on reading.  Thus, when opening a binary file, you should append ``'b'`` to
	the *mode* value to open the file in binary mode, which will improve
	portability.  (Appending ``'b'`` is useful even on systems that don't treat
	binary and text files differently, where it serves as documentation.)  See below
	for more possible values of *mode*.
	
	"""
	pass
	
def ord(c):
	"""
	Given a string of length one, return an integer representing the Unicode code
	point of the character when the argument is a unicode object, or the value of
	the byte when the argument is an 8-bit string. For example, ``ord('a')`` returns
	the integer ``97``, ``ord(u'\u2020')`` returns ``8224``.  This is the inverse of
	:func:`chr` for 8-bit strings and of :func:`unichr` for unicode objects.  If a
	unicode argument is given and Python was built with UCS2 Unicode, then the
	character's code point must be in the range [0..65535] inclusive; otherwise the
	string length is two, and a :exc:`TypeError` will be raised.
	
	
	"""
	pass
	
def pow(x,y,z):
	"""
	Return *x* to the power *y*; if *z* is present, return *x* to the power *y*,
	modulo *z* (computed more efficiently than ``pow(x, y) % z``). The two-argument
	form ``pow(x, y)`` is equivalent to using the power operator: ``x**y``.
	
	The arguments must have numeric types.  With mixed operand types, the coercion
	rules for binary arithmetic operators apply.  For int and long int operands, the
	result has the same type as the operands (after coercion) unless the second
	argument is negative; in that case, all arguments are converted to float and a
	float result is delivered.  For example, ``10**2`` returns ``100``, but
	``10**-2`` returns ``0.01``.  (This last feature was added in Python 2.2.  In
	Python 2.1 and before, if both arguments were of integer types and the second
	argument was negative, an exception was raised.) If the second argument is
	negative, the third argument must be omitted. If *z* is present, *x* and *y*
	must be of integer types, and *y* must be non-negative.  (This restriction was
	added in Python 2.2.  In Python 2.1 and before, floating 3-argument ``pow()``
	returned platform-dependent results depending on floating-point rounding
	accidents.)
	
	
	"""
	pass
	
def property(fget,fset,fdel,doc):
	"""
	Return a property attribute for :term:`new-style class`\es (classes that
	derive from :class:`object`).
	
	*fget* is a function for getting an attribute value, likewise *fset* is a
	function for setting, and *fdel* a function for del'ing, an attribute.  Typical
	use is to define a managed attribute ``x``::
	
	class C(object):
	def __init__(self):
	self._x = None
	
	def getx(self):
	return self._x
	def setx(self, value):
	self._x = value
	def delx(self):
	del self._x
	x = property(getx, setx, delx, "I'm the 'x' property.")
	
	If then *c* is an instance of *C*, ``c.x`` will invoke the getter,
	``c.x = value`` will invoke the setter and ``del c.x`` the deleter.
	
	If given, *doc* will be the docstring of the property attribute. Otherwise, the
	property will copy *fget*'s docstring (if it exists).  This makes it possible to
	create read-only properties easily using :func:`property` as a :term:`decorator`::
	
	class Parrot(object):
	def __init__(self):
	self._voltage = 100000
	
	@property
	def voltage(self):
	 " " " Get the current voltage. " " " 
	return self._voltage
	
	turns the :meth:`voltage` method into a "getter" for a read-only attribute
	with the same name.
	
	A property object has :attr:`getter`, :attr:`setter`, and :attr:`deleter`
	methods usable as decorators that create a copy of the property with the
	corresponding accessor function set to the decorated function.  This is
	best explained with an example::
	
	class C(object):
	def __init__(self):
	self._x = None
	
	@property
	def x(self):
	 " " " I'm the 'x' property. " " " 
	return self._x
	
	@x.setter
	def x(self, value):
	self._x = value
	
	@x.deleter
	def x(self):
	del self._x
	
	This code is exactly equivalent to the first example.  Be sure to give the
	additional functions the same name as the original property (``x`` in this
	case.)
	
	The returned property also has the attributes ``fget``, ``fset``, and
	``fdel`` corresponding to the constructor arguments.
	
	"""
	pass
	
def range(start,stop,step):
	"""
	This is a versatile function to create lists containing arithmetic progressions.
	It is most often used in :keyword:`for` loops.  The arguments must be plain
	integers.  If the *step* argument is omitted, it defaults to ``1``.  If the
	*start* argument is omitted, it defaults to ``0``.  The full form returns a list
	of plain integers ``[start, start + step, start + 2 * step, more]``.  If *step*
	is positive, the last element is the largest ``start + i * step`` less than
	*stop*; if *step* is negative, the last element is the smallest ``start + i *
	step`` greater than *stop*.  *step* must not be zero (or else :exc:`ValueError`
	is raised).  Example:
	
	>>> range(10)
	[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
	>>> range(1, 11)
	[1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
	>>> range(0, 30, 5)
	[0, 5, 10, 15, 20, 25]
	>>> range(0, 10, 3)
	[0, 3, 6, 9]
	>>> range(0, -10, -1)
	[0, -1, -2, -3, -4, -5, -6, -7, -8, -9]
	>>> range(0)
	[]
	>>> range(1, 0)
	[]
	
	
	"""
	pass
	
def raw_input(prompt):
	"""
	If the *prompt* argument is present, it is written to standard output without a
	trailing newline.  The function then reads a line from input, converts it to a
	string (stripping a trailing newline), and returns that. When EOF is read,
	:exc:`EOFError` is raised. Example::
	
	>>> s = raw_input('--> ')
	--> Monty Python's Flying Circus
	>>> s
	"Monty Python's Flying Circus"
	
	If the :mod:`readline` module was loaded, then :func:`raw_input` will use it to
	provide elaborate line editing and history features.
	
	
	"""
	pass
	
def reduce(function,iterable,initializer):
	"""
	Apply *function* of two arguments cumulatively to the items of *iterable*, from
	left to right, so as to reduce the iterable to a single value.  For example,
	``reduce(lambda x, y: x+y, [1, 2, 3, 4, 5])`` calculates ``((((1+2)+3)+4)+5)``.
	The left argument, *x*, is the accumulated value and the right argument, *y*, is
	the update value from the *iterable*.  If the optional *initializer* is present,
	it is placed before the items of the iterable in the calculation, and serves as
	a default when the iterable is empty.  If *initializer* is not given and
	*iterable* contains only one item, the first item is returned.
	
	
	"""
	pass
	
def reload(module):
	"""
	Reload a previously imported *module*.  The argument must be a module object, so
	it must have been successfully imported before.  This is useful if you have
	edited the module source file using an external editor and want to try out the
	new version without leaving the Python interpreter.  The return value is the
	module object (the same as the *module* argument).
	
	When ``reload(module)`` is executed:
	
	* Python modules' code is recompiled and the module-level code reexecuted,
	defining a new set of objects which are bound to names in the module's
	dictionary.  The ``init`` function of extension modules is not called a second
	time.
	
	* As with all other objects in Python the old objects are only reclaimed after
	their reference counts drop to zero.
	
	* The names in the module namespace are updated to point to any new or changed
	objects.
	
	* Other references to the old objects (such as names external to the module) are
	not rebound to refer to the new objects and must be updated in each namespace
	where they occur if that is desired.
	
	There are a number of other caveats:
	
	If a module is syntactically correct but its initialization fails, the first
	:keyword:`import` statement for it does not bind its name locally, but does
	store a (partially initialized) module object in ``sys.modules``.  To reload the
	module you must first :keyword:`import` it again (this will bind the name to the
	partially initialized module object) before you can :func:`reload` it.
	
	When a module is reloaded, its dictionary (containing the module's global
	variables) is retained.  Redefinitions of names will override the old
	definitions, so this is generally not a problem.  If the new version of a module
	does not define a name that was defined by the old version, the old definition
	remains.  This feature can be used to the module's advantage if it maintains a
	global table or cache of objects --- with a :keyword:`try` statement it can test
	for the table's presence and skip its initialization if desired::
	
	try:
	cache
	except NameError:
	cache = {}
	
	It is legal though generally not very useful to reload built-in or dynamically
	loaded modules, except for :mod:`sys`, :mod:`__main__` and :mod:`__builtin__`.
	In many cases, however, extension modules are not designed to be initialized
	more than once, and may fail in arbitrary ways when reloaded.
	
	If a module imports objects from another module using :keyword:`from` more
	:keyword:`import` more, calling :func:`reload` for the other module does not
	redefine the objects imported from it --- one way around this is to re-execute
	the :keyword:`from` statement, another is to use :keyword:`import` and qualified
	names (*module*.*name*) instead.
	
	If a module instantiates instances of a class, reloading the module that defines
	the class does not affect the method definitions of the instances --- they
	continue to use the old class definition.  The same is true for derived classes.
	
	
	"""
	pass
	
def repr(object):
	"""
	Return a string containing a printable representation of an object.  This is
	the same value yielded by conversions (reverse quotes).  It is sometimes
	useful to be able to access this operation as an ordinary function.  For many
	types, this function makes an attempt to return a string that would yield an
	object with the same value when passed to :func:`eval`, otherwise the
	representation is a string enclosed in angle brackets that contains the name
	of the type of the object together with additional information often
	including the name and address of the object.  A class can control what this
	function returns for its instances by defining a :meth:`__repr__` method.
	
	
	"""
	pass
	
def reversed(seq):
	"""
	Return a reverse :term:`iterator`.  *seq* must be an object which has
	a :meth:`__reversed__` method or supports the sequence protocol (the
	:meth:`__len__` method and the :meth:`__getitem__` method with integer
	arguments starting at ``0``).
	
	"""
	pass
	
def round(x,n):
	"""
	Return the floating point value *x* rounded to *n* digits after the decimal
	point.  If *n* is omitted, it defaults to zero. The result is a floating point
	number.  Values are rounded to the closest multiple of 10 to the power minus
	*n*; if two multiples are equally close, rounding is done away from 0 (so. for
	example, ``round(0.5)`` is ``1.0`` and ``round(-0.5)`` is ``-1.0``).
	
	
	"""
	pass
	
def set(iterable):
	""":noindex:
	
	Return a new set, optionally with elements taken from *iterable*.
	The set type is described in :ref:`types-set`.
	
	For other containers see the built in :class:`dict`, :class:`list`, and
	:class:`tuple` classes, and the :mod:`collections` module.
	
	"""
	pass
	
def setattr(object,name,value):
	"""
	This is the counterpart of :func:`getattr`.  The arguments are an object, a
	string and an arbitrary value.  The string may name an existing attribute or a
	new attribute.  The function assigns the value to the attribute, provided the
	object allows it.  For example, ``setattr(x, 'foobar', 123)`` is equivalent to
	``x.foobar = 123``.
	
	
	"""
	pass
	
def slice(start,stop,step):
	"""
	"""
	pass
	
def sorted(iterable,cmp,key,reverse):
	"""
	Return a new sorted list from the items in *iterable*.
	
	The optional arguments *cmp*, *key*, and *reverse* have the same meaning as
	those for the :meth:`list.sort` method (described in section
	:ref:`typesseq-mutable`).
	
	*cmp* specifies a custom comparison function of two arguments (iterable
	elements) which should return a negative, zero or positive number depending on
	whether the first argument is considered smaller than, equal to, or larger than
	the second argument: ``cmp=lambda x,y: cmp(x.lower(), y.lower())``.  The default
	value is ``None``.
	
	*key* specifies a function of one argument that is used to extract a comparison
	key from each list element: ``key=str.lower``.  The default value is ``None``
	(compare the elements directly).
	
	*reverse* is a boolean value.  If set to ``True``, then the list elements are
	sorted as if each comparison were reversed.
	
	In general, the *key* and *reverse* conversion processes are much faster
	than specifying an equivalent *cmp* function.  This is because *cmp* is
	called multiple times for each list element while *key* and *reverse* touch
	each element only once.  Use :func:`functools.cmp_to_key` to convert an
	old-style *cmp* function to a *key* function.
	
	For sorting examples and a brief sorting tutorial, see `Sorting HowTo
	<http://wiki.python.org/moin/HowTo/Sorting/>`_\.
	
	"""
	pass
	
def staticmethod(function):
	"""
	Return a static method for *function*.
	
	A static method does not receive an implicit first argument. To declare a static
	method, use this idiom::
	
	class C:
	@staticmethod
	def f(arg1, arg2, more): more
	
	The ``@staticmethod`` form is a function :term:`decorator` -- see the
	description of function definitions in :ref:`function` for details.
	
	It can be called either on the class (such as ``C.f()``) or on an instance (such
	as ``C().f()``).  The instance is ignored except for its class.
	
	Static methods in Python are similar to those found in Java or C++. For a more
	advanced concept, see :func:`classmethod` in this section.
	
	For more information on static methods, consult the documentation on the
	standard type hierarchy in :ref:`types`.
	
	"""
	pass
	
def str(object):
	"""
	Return a string containing a nicely printable representation of an object.  For
	strings, this returns the string itself.  The difference with ``repr(object)``
	is that ``str(object)`` does not always attempt to return a string that is
	acceptable to :func:`eval`; its goal is to return a printable string.  If no
	argument is given, returns the empty string, ``''``.
	
	For more information on strings see :ref:`typesseq` which describes sequence
	functionality (strings are sequences), and also the string-specific methods
	described in the :ref:`string-methods` section. To output formatted strings
	use template strings or the ``%`` operator described in the
	:ref:`string-formatting` section. In addition see the :ref:`stringservices`
	section. See also :func:`unicode`.
	
	
	"""
	pass
	
def sum(iterable,start):
	"""
	Sums *start* and the items of an *iterable* from left to right and returns the
	total.  *start* defaults to ``0``. The *iterable*'s items are normally numbers,
	and the start value is not allowed to be a string.
	
	For some use cases, there are good alternatives to :func:`sum`.
	The preferred, fast way to concatenate a sequence of strings is by calling
	``''.join(sequence)``.  To add floating point values with extended precision,
	see :func:`math.fsum`\.  To concatenate a series of iterables, consider using
	:func:`itertools.chain`.
	
	"""
	pass
	
def super(type,object_or_type):
	"""
	Return a proxy object that delegates method calls to a parent or sibling
	class of *type*.  This is useful for accessing inherited methods that have
	been overridden in a class. The search order is same as that used by
	:func:`getattr` except that the *type* itself is skipped.
	
	The :attr:`__mro__` attribute of the *type* lists the method resolution
	search order used by both :func:`getattr` and :func:`super`.  The attribute
	is dynamic and can change whenever the inheritance hierarchy is updated.
	
	If the second argument is omitted, the super object returned is unbound.  If
	the second argument is an object, ``isinstance(obj, type)`` must be true.  If
	the second argument is a type, ``issubclass(type2, type)`` must be true (this
	is useful for classmethods).
	
	"""
	pass
	
def tuple(iterable):
	"""
	Return a tuple whose items are the same and in the same order as *iterable*'s
	items.  *iterable* may be a sequence, a container that supports iteration, or an
	iterator object. If *iterable* is already a tuple, it is returned unchanged.
	For instance, ``tuple('abc')`` returns ``('a', 'b', 'c')`` and ``tuple([1, 2,
	3])`` returns ``(1, 2, 3)``.  If no argument is given, returns a new empty
	tuple, ``()``.
	
	:class:`tuple` is an immutable sequence type, as documented in
	:ref:`typesseq`. For other containers see the built in :class:`dict`,
	:class:`list`, and :class:`set` classes, and the :mod:`collections` module.
	
	
	"""
	pass
	
def type(object):
	"""
	"""
	pass
	
def type(name,bases,dict):
	""":noindex:
	
	Return a new type object.  This is essentially a dynamic form of the
	:keyword:`class` statement. The *name* string is the class name and becomes the
	:attr:`__name__` attribute; the *bases* tuple itemizes the base classes and
	becomes the :attr:`__bases__` attribute; and the *dict* dictionary is the
	namespace containing definitions for class body and becomes the :attr:`__dict__`
	attribute.  For example, the following two statements create identical
	:class:`type` objects:
	
	>>> class X(object):
	more     a = 1
	more
	>>> X = type('X', (object,), dict(a=1))
	
	"""
	pass
	
def unichr(i):
	"""
	Return the Unicode string of one character whose Unicode code is the integer
	*i*.  For example, ``unichr(97)`` returns the string ``u'a'``.  This is the
	inverse of :func:`ord` for Unicode strings.  The valid range for the argument
	depends how Python was configured -- it may be either UCS2 [0..0xFFFF] or UCS4
	[0..0x10FFFF]. :exc:`ValueError` is raised otherwise. For ASCII and 8-bit
	strings see :func:`chr`.
	
	"""
	pass
	
def unicode(object,encoding,errors):
	"""
	Return the Unicode string version of *object* using one of the following modes:
	
	If *encoding* and/or *errors* are given, ``unicode()`` will decode the object
	which can either be an 8-bit string or a character buffer using the codec for
	*encoding*. The *encoding* parameter is a string giving the name of an encoding;
	if the encoding is not known, :exc:`LookupError` is raised. Error handling is
	done according to *errors*; this specifies the treatment of characters which are
	invalid in the input encoding.  If *errors* is ``'strict'`` (the default), a
	:exc:`ValueError` is raised on errors, while a value of ``'ignore'`` causes
	errors to be silently ignored, and a value of ``'replace'`` causes the official
	Unicode replacement character, ``U+FFFD``, to be used to replace input
	characters which cannot be decoded.  See also the :mod:`codecs` module.
	
	If no optional parameters are given, ``unicode()`` will mimic the behaviour of
	``str()`` except that it returns Unicode strings instead of 8-bit strings. More
	precisely, if *object* is a Unicode string or subclass it will return that
	Unicode string without any additional decoding applied.
	
	For objects which provide a :meth:`__unicode__` method, it will call this method
	without arguments to create a Unicode string. For all other objects, the 8-bit
	string version or representation is requested and then converted to a Unicode
	string using the codec for the default encoding in ``'strict'`` mode.
	
	For more information on Unicode strings see :ref:`typesseq` which describes
	sequence functionality (Unicode strings are sequences), and also the
	string-specific methods described in the :ref:`string-methods` section. To
	output formatted strings use template strings or the ``%`` operator described
	in the :ref:`string-formatting` section. In addition see the
	:ref:`stringservices` section. See also :func:`str`.
	
	"""
	pass
	
def vars(object):
	"""
	Without an argument, act like :func:`locals`.
	
	With a module, class or class instance object as argument (or anything else that
	has a :attr:`__dict__` attribute), return that attribute.
	
	"""
	pass
	
def xrange(start,stop,step):
	"""
	This function is very similar to :func:`range`, but returns an "xrange object"
	instead of a list.  This is an opaque sequence type which yields the same values
	as the corresponding list, without actually storing them all simultaneously.
	The advantage of :func:`xrange` over :func:`range` is minimal (since
	:func:`xrange` still has to create the values when asked for them) except when a
	very large range is used on a memory-starved machine or when all of the range's
	elements are never used (such as when the loop is usually terminated with
	:keyword:`break`).
	
	"""
	pass
	
def zip(iterable,more):
	"""
	This function returns a list of tuples, where the *i*-th tuple contains the
	*i*-th element from each of the argument sequences or iterables. The returned
	list is truncated in length to the length of the shortest argument sequence.
	When there are multiple arguments which are all of the same length, :func:`zip`
	is similar to :func:`map` with an initial argument of ``None``. With a single
	sequence argument, it returns a list of 1-tuples. With no arguments, it returns
	an empty list.
	
	The left-to-right evaluation order of the iterables is guaranteed. This
	makes possible an idiom for clustering a data series into n-length groups
	using ``zip(*[iter(s)]*n)``.
	
	:func:`zip` in conjunction with the ``*`` operator can be used to unzip a
	list::
	
	>>> x = [1, 2, 3]
	>>> y = [4, 5, 6]
	>>> zipped = zip(x, y)
	>>> zipped
	[(1, 4), (2, 5), (3, 6)]
	>>> x2, y2 = zip(*zipped)
	>>> x == list(x2) and y == list(y2)
	True
	
	"""
	pass
	
def __import__(name,globals,locals,_fromlist,level):
	"""
	"""
	pass
	
def apply(function,args,keywords):
	"""
	The *function* argument must be a callable object (a user-defined or built-in
	function or method, or a class object) and the *args* argument must be a
	sequence.  The *function* is called with *args* as the argument list; the number
	of arguments is the length of the tuple. If the optional *keywords* argument is
	present, it must be a dictionary whose keys are strings.  It specifies keyword
	arguments to be added to the end of the argument list. Calling :func:`apply` is
	different from just calling ``function(args)``, since in that case there is
	always exactly one argument.  The use of :func:`apply` is equivalent to
	``function(*args, **keywords)``.
	
	"""
	pass
	
def buffer(object,offset,size):
	"""
	The *object* argument must be an object that supports the buffer call interface
	(such as strings, arrays, and buffers).  A new buffer object will be created
	which references the *object* argument. The buffer object will be a slice from
	the beginning of *object* (or from the specified *offset*). The slice will
	extend to the end of *object* (or will have a length given by the *size*
	argument).
	
	
	"""
	pass
	
def coerce(x,y):
	"""
	Return a tuple consisting of the two numeric arguments converted to a common
	type, using the same rules as used by arithmetic operations. If coercion is not
	possible, raise :exc:`TypeError`.
	
	
	"""
	pass
	
def intern(string):
	"""
	Enter *string* in the table of "interned" strings and return the interned string
	-- which is *string* itself or a copy. Interning strings is useful to gain a
	little performance on dictionary lookup -- if the keys in a dictionary are
	interned, and the lookup key is interned, the key comparisons (after hashing)
	can be done by a pointer compare instead of a string compare.  Normally, the
	names used in Python programs are automatically interned, and the dictionaries
	used to hold module, class or instance attributes have interned keys.
	
	"""
	pass
	



#!/usr/bin/env python2.7
# This file is part of KDevelop
# SPDX-FileCopyrightText: 2011 Victor Varvariuc <victor.varvariuc@gmail.com>
# SPDX-FileCopyrightText: 2011 Sven Brauch <svenbrauch@googlemail.com>

import sys
from xml.dom import minidom


class NoDefaultValue():
    '''Unique object for marking absence of a default value for a function argument.'''

def indentCode(code, level):
    '''Indent given source code.'''
    return '\n'.join('    ' * level + line for line in code.splitlines())

def getNodeNames(node):
    '''Return node name. Chop the beginning of the name if it starts with parent's prefix:
    QWidget.RenderFlags.__init__ -> __init__'''
    name = node.attributes['name'].value
    parentNode = node.parentNode
    if parentNode.nodeName == 'Enum': # for unem members name prefix is not enum's name, but its parent's
       parentNode = parentNode.parentNode
    
    parentName = []
    while parentNode.nodeName == 'Class':
        parentName.append(parentNode.attributes['name'].value)
        parentNode = parentNode.parentNode
    parentName = list(reversed(parentName))
    parentName = '.'.join(parentName) + '.'
    
    if name.startswith(parentName):
        return name[len(parentName):], name
    return name, name


def parseEnum(enumNode):
    '''Parse Enum node and return its source code.'''
    enumMembers = []
    enumName, enumFullName = getNodeNames(enumNode)
    for node in enumNode.childNodes:
        if node.nodeType == node.ELEMENT_NODE:
            if node.nodeName == 'EnumMember':
                #print getNodeNames(node)
                enumMemberName = getNodeNames(node)[0]
                if enumMemberName == 'None':
                    enumMemberName = '__kdevpythondocumentation_builtin_None'
                enumMembers.append(enumMemberName)
            else:
                print 'Unknown sub-node in Enum %s: %s' % (enumFullName, node.nodeName)
    text = '# Enum %s\n' % enumFullName
    for enumMember in enumMembers:
        text += '%s = 0\n' % enumMember
    return text


def parseFunction(functionNode):
    '''Parse Function node and return its code.'''
    params = []
    retType = 'void'
    funcName, funcFullName = getNodeNames(functionNode)
    for node in functionNode.childNodes:
        if node.nodeType == node.ELEMENT_NODE:
            if not node.hasAttribute('typename'):
                node.attributes['typename'] = 'unknown'
            if node.nodeName == 'Argument':
                argType = node.attributes['typename'].value
                try:
                    argName = '*args' if argType == '...' else node.attributes['name'].value
                except KeyError: # no `name` attribute - it's function return value type
                    retType = argType
                else:
                    try: # some arguments have default values
                        defaultValue = node.attributes['default'].value
                    except KeyError:
                        defaultValue = NoDefaultValue
                    try:
                        defaultValue = defaultValue.replace("QString", "str")
                        defaultValue = defaultValue.replace("QChar", "bytes")
                    except AttributeError:
                        pass
                    params.append((argType, argName, defaultValue))
            else:
                print 'Unhandled sub-node type in function %s: %s' % (funcFullName, node.nodeName)

    descr = 'abstract ' if 'abstract' in functionNode.attributes.keys() else ''
    descr += 'static ' if 'static' in functionNode.attributes.keys() else ''

    namesUsed = set(['self', 'exec', 'print', 'from', 'in', 'def', 'if', 'for',
                     'while', 'return', 'raise', 'pass', 'global', 'del']) # reserved words which cannot be used as argument names
    if funcFullName in namesUsed:
        funcFullName += '_'
    
    # function parameters in description
    paramsStr = []
    for p in params:
        paramsStr.append('{} {}'.format(*p) if p[2] is NoDefaultValue else '{} {} = {}'.format(*p))
    descr += '%s %s(%s)' % (retType, funcFullName, ', '.join(paramsStr))

    # function parameters in function definition
    paramsStr = ['self'] if functionNode.parentNode.nodeName == 'Class' else [] # add `self` first parameter for methods
    hadDefault = False # there has been a default argument previously
    for _, argName, defaultValue in params:
        while argName in namesUsed: # some function arguments have same names...
            print 'Adjusting arg name: `%s` in `%s`' % (argName, funcFullName) # http://www.riverbankcomputing.co.uk/static/Docs/PyQt4/html/qdatetime.html#QDateTime-5
            argName = argName + '_'
        namesUsed.add(argName)
        if defaultValue is NoDefaultValue and not hadDefault:
            paramsStr.append(argName)
        else:
            if defaultValue is NoDefaultValue or not defaultValue.replace('(','').replace(')','').isalnum():
                defaultValue = "None"
            paramsStr.append('{} = {}'.format(argName, defaultValue))
            hadDefault = True

    text = "def %s(%s):\n    '''%s'''\n" % (funcName, ', '.join(paramsStr), descr)
    if retType == 'void':
        return text # do not print `return None` statement
    if retType.startswith('list-of-'):
        retType = '[' + retType[8:] + '()]'
    elif retType.find("-or-") != -1:
        a, b = retType.split("-or-")
        retType = "{0}() if True else {1}()".format(a, b)
    elif retType.startswith("dict-of-"):
        q = retType[8:].split('-')
        key, value = q[0], q[1]
        retType = '{' + key + "():" + value + "()}"
    else:
        retType += '()'
    retType = retType.replace("QString", "str")
    retType = retType.replace("QChar", "bytes")
    retType = retType.replace("const", "")

    return text + '    return %s' % retType


def parseClass(classNode):
    '''Parse Class node and return its api python code.'''
    className, classFullName = getNodeNames(classNode)
    try:
        parentClasses = classNode.attributes['inherits'].value.split()
    except KeyError:
        parentClasses = []
    text = 'class %s(%s):\n    """"""\n' % (className, ', '.join(parentClasses))
    for node in classNode.childNodes:
        if node.nodeType == node.ELEMENT_NODE:
            if node.nodeName == 'Member':
                text += '    %s = None # %s - member\n' % (getNodeNames(node)[0], node.attributes['typename'].value)
            elif node.nodeName == 'Function':
                name = getNodeNames(node)[0]
                if name not in ('exec', 'print'): # skip these invalid for Python names
                    text += indentCode(parseFunction(node), 1) + '\n'
            elif node.nodeName == 'Enum':
                text += indentCode(parseEnum(node), 1) + '\n\n'
            elif node.nodeName == 'Class':
                text += indentCode(parseClass(node), 1) + '\n'
            elif node.nodeName == 'Signal':
                text += '    %s = pyqtSignal() # %s - signal\n' % (getNodeNames(node)[0], node.attributes['sig'].value)
            else:
                print 'Unhandled sub-node type in class %s: %s' % (classFullName, node.nodeName)
    return text


def convertXmlToPy(inFilePath):
    print '\nConverting .xml PyQt5 module (%s) to .py' % inFilePath

    print 'Parsing xml...'
    dom = minidom.parse(inFilePath)

    module = dom.firstChild
    assert module.nodeName == 'Module'
    moduleName = module.attributes['name'].value
    print 'Module name:', moduleName

    outFilePath = moduleName + '.py'
    stats = {}

    with open(outFilePath, 'w') as file:
        file.write('class pyqtSignal():\n def connect(self, targetSignal): pass\n def emit(self, *args): pass\n')
        file.write('from QtCore import *\n\n')
        file.write('from QtWidgets import *\n\n')
        file.write('import datetime\n\n')
        for node in module.childNodes:
            if node.nodeType != node.ELEMENT_NODE:
                continue # skip non element nodes
            nodeName = node.nodeName
            stats[nodeName] = stats.setdefault(nodeName, 0) + 1 # stats
            if nodeName == 'Class':
                file.write(parseClass(node) + '\n\n')
            elif nodeName == 'Function':
                if not 'extends' in node.attributes.keys(): # skip module level functions, which extend unpresent here class
                    file.write(parseFunction(node) + '\n\n')
            elif nodeName == 'Member':
                file.write('%s = None # %s member\n\n' % (getNodeNames(node)[0], node.attributes['typename'].value))
            elif nodeName == 'Enum':
                file.write(parseEnum(node) + '\n\n')
            else:
                print 'Unhandled node type in the module:', nodeName

    print 'Stats:', stats


files = sys.argv[1:] # ['QtGui', 'QtCore'] # modules to convert

for fileName in files:
    convertXmlToPy(fileName)
